/*
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */

import * as moment from "moment";

export interface CultureModel {
  /**
   * ISO 639-1 (language) and ISO 3166-1 (country) code.
  */
  cultureCode: string;
  /**
   * Full name of the language and country.
  */
  cultureName: string;
  /**
   * Symbol of the currency.
  */
  currencySymbol: string;
}

export interface PlaintextCustomerIdentifierModel {
  /**
   * Secret text to vault.
  */
  plaintext: string;
  /**
   * Client provided identifier tying the tokens back to some other client data.
  */
  customIdentifier?: string;
}

export interface TokenCustomIdentifierModel {
  /**
   * Reference to the vaulted secret.
  */
  token: string;
  /**
   * Client provided identifier tying the tokens back to some other client data.
  */
  customIdentifier?: string;
}

export interface TokenModel {
  /**
   * Reference to the vaulted secret.
  */
  token: string;
}

export interface CardModel {
  /**
   * Card number.
  */
  ccn: string;
  /**
   * Full name located on the card.
  */
  fullName: string;
  /**
   * Expiration month.
  */
  expMonth: number;
  /**
   * Expiration year.
  */
  expYear: number;
  /**
   * Card verification value (security code). This value is not stored permanently.
  */
  cvv?: string;
  /**
   * Type of card (amex, diners_club_carte_blanche, diners_club_international,
   * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro, uatp, mir).
  */
  cardType: string;
  /**
   * Remaining ttl before the CVV gets deleted.
  */
  cvvTtl: number;
  /**
   * The card's time to live in seconds. Once expired the
   * card is deleted from the vault.
  */
  ttl?: number;
}

export interface CardTokenModel {
  /**
   * Card token.
  */
  token: string;
}

export interface ClientErrorModel {
  /**
   * Client error message.
  */
  message?: string;
}

export interface ServerErrorModel {
  /**
   * A reference to the type of error
   * returned.
  */
  type?: string;
  /**
   * Title/summary of the error.
  */
  title?: string;
  /**
   * HTTP status code.
  */
  status?: number;
  /**
   * Detailed error message.
  */
  detail?: string;
  /**
   * Identifies the request associated
   * with the error.
  */
  traceId?: string;
}

export interface CardReadModel {
  /**
   * First six digits of the card number.
  */
  firstSix: string;
  /**
   * Last four digits of the card number.
  */
  lastFour: string;
  /**
   * Card number.
  */
  ccn?: string;
  /**
   * Expiration month.
  */
  expMonth: number;
  /**
   * Expiration year.
  */
  expYear: number;
  /**
   * Full name located on the card.
  */
  fullName: string;
  /**
   * Type of card (amex, diners_club_carte_blanche, diners_club_international,
   * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro, uatp, mir).
  */
  cardType: string;
  /**
   * Remaining ttl before the CVV gets deleted.
  */
  cvvTtl: number;
  /**
   * Remaining ttl before the card gets deleted. If -1, card lives forever until manually deleted.
  */
  ttl: number;
}

export interface EphemeralKeyModel {
  /**
   * One time use expiring key.
  */
  ephemeralKey?: string;
}

export interface CardTtlReadModel {
  /**
   * The card's CVV time to live in seconds. Once expired the
   * CVV is deleted from the vault.
  */
  cvvTtl: number;
  /**
   * The card's time to live in seconds. Once expired the
   * card is deleted from the vault. If -1, card lives forever until
   * manually deleted.
  */
  ttl: number;
}

export interface CardTtlModel {
  /**
   * The card's time to live in seconds. Once expired the
   * card is deleted from the vault. If -1, card lives forever until
   * manually deleted.
  */
  ttl: number;
}

export interface HeadersModel {
  /**
   * Name of the header.
  */
  name: string;
  /**
   * Value of the header.
  */
  value: string;
}

export interface CardProxyModel {
  /**
   * URL to use on the payment gateway request.
  */
  url: string;
  /**
   * HTTP method to use on the payment gateway request.
  */
  httpMethod: string;
  /**
   * Headers to use on the payment gateway request.
  */
  headers?: HeadersModel[];
  /**
   * Body to use on the payment gateway request.
  */
  body?: string;
}

export interface GatewayResponseModel {
  /**
   * Headers from the payment gateway response.
  */
  headers?: HeadersModel[];
  /**
   * HTTP status code from the payment gateway response.
  */
  statusCode: number;
  /**
   * Content type from the payment gateway response.
  */
  contentType: string;
  /**
   * Body from the payment gateway response.
  */
  body: string;
}

export interface GatewayRequestModel {
  /**
   * URL to use on the payment gateway request.
  */
  url: string;
  /**
   * HTTP method to use on the payment gateway request.
  */
  httpMethod: string;
  /**
   * Headers to use on the payment gateway request.
  */
  headers?: HeadersModel[];
  /**
   * Body to use on the payment gateway request.
  */
  body?: string;
}

export interface CartItemModel {
  /**
   * Description of the cart item.
  */
  description: string;
  /**
   * Cost of the cart item.
  */
  amount: number;
}

export interface CartModel {
  /**
   * ISO 639-1 (language) and ISO 3166-1 (country) code.
  */
  cultureCode: string;
  /**
   * List of cart items.
  */
  cartItems: CartItemModel[];
  /**
   * Total of the cart item amounts. The total is validated against the
   * sum of the cart item amounts.
  */
  total: number;
  /**
   * Some payment gateways only accept integers. If true, it will multiply
   * the total by 100. For instance, 10.01 will be submitted to the gateway
   * as 1001.
  */
  gatewayIntegersOnly: boolean;
}

export interface CardProcessModel {
  gatewayRequest: GatewayRequestModel;
  cart: CartModel;
}

export interface CardFormUrlModel {
  /**
   * URL to the requested form.
  */
  url: string;
}

export interface CardGatewayCartResponseModel {
  gatewayResponse?: GatewayResponseModel;
  cart?: CartModel;
  /**
   * Card token.
  */
  token?: string;
}

export interface PlaintextModel {
  /**
   * Secret text.
  */
  plaintext: string;
}

export interface UploadUrlModel {
  /**
   * The URL to PUT the file. The URL expires in 5 minutes.
  */
  url: string;
  /**
   * Tokenized file name.
  */
  fileName: string;
  /**
   * WebSocket URL to receive messages on the status of the file.
   * It returns the following jSON response
   * {"status":"string","detailedMessage":"string","url":"string"}
   * The status can be one of the following: Waiting on upload, Encrypting, Vaulted, Decrypting,
   * Decrypted, Error.
   * The url property will contain a download url when the status is Decrypted. The download url is
   * valid for 5 minutes.
  */
  wsUrl: string;
}

export interface FileStatusModel {
  fileStatus: string;
}

export interface DownloadUrlModel {
  /**
   * The URL to GET the decrypted file. The URL expires in 5 minutes.
  */
  url: string;
}

export interface WsUrlModel {
  /**
   * WebSocket URL to receive messages on the status of the file.
   * It returns the following jSON response
   * {"status":"string","detailedMessage":"string","url":"string"}
   * The status can be one of the following: Waiting on upload, Encrypting, Vaulted, Decrypting,
   * Decrypted, Error.
   * The url property will contain a download url when the status is Decrypted. The download url is
   * valid for 5 minutes.
  */
  wsUrl?: string;
}
