/*
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

/* jshint latedef:false */
/* jshint forin:false */
/* jshint noempty:false */

'use strict';

const msRest = require('ms-rest');
const ServiceClient = msRest.ServiceClient;
const WebResource = msRest.WebResource;

const models = require('./models');


/**
 * @summary Store a card.
 *
 * When a card is stored in the vault, the original card information is not
 * retrievable by the client without the cardvault_raw scope (contact support).
 * The CVV's ttl is set to the same ttl as the card unless the card is stored
 * permanently. If the card is stored permanently, the CVV's ttl is set to 30
 * minutes. The CVV is purged after its first use or after its ttl expires,
 * whichever comes first. After the card's ttl, the card is deleted. To make
 * the card permanent, leave out the ttl property. The full card number can be
 * used through the proxy endpoint. You can get the first six, the last four,
 * full name, and expiration from /cardvault/cards (GET).
 *
 * @param {object} body Card information.
 *
 * @param {string} body.ccn Card number.
 *
 * @param {string} body.fullName Full name located on the card.
 *
 * @param {number} body.expMonth Expiration month.
 *
 * @param {number} body.expYear Expiration year.
 *
 * @param {string} [body.cvv] Card verification value (security code). This
 * value is not stored permanently.
 *
 * @param {string} body.cardType Type of card (amex, diners_club_carte_blanche,
 * diners_club_international,
 * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro,
 * uatp, mir).
 *
 * @param {number} body.cvvTtl Remaining ttl before the CVV gets deleted.
 *
 * @param {number} [body.ttl] The card's time to live in seconds. Once expired
 * the
 * card is deleted from the vault.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {boolean} [options.preserveFormat] If true, a Luhn passable token is
 * returned consisting of the original first six and last four.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _storeCard(body, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let preserveFormat = (options && options.preserveFormat !== undefined) ? options.preserveFormat : undefined;
  // Validate
  try {
    if (body === null || body === undefined) {
      throw new Error('body cannot be null or undefined.');
    }
    if (preserveFormat !== null && preserveFormat !== undefined && typeof preserveFormat !== 'boolean') {
      throw new Error('preserveFormat must be of type boolean.');
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/cards';
  let queryParameters = [];
  if (preserveFormat !== null && preserveFormat !== undefined) {
    queryParameters.push('preserveFormat=' + encodeURIComponent(preserveFormat.toString()));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'POST';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  // Serialize Request
  let requestContent = null;
  let requestModel = null;
  try {
    if (body !== null && body !== undefined) {
      let requestModelMapper = new client.models['CardModel']().mapper();
      requestModel = client.serialize(requestModelMapper, body, 'body');
      requestContent = JSON.stringify(requestModel);
    }
  } catch (error) {
    let serializationError = new Error(`Error "${error.message}" occurred in serializing the ` +
        `payload - ${JSON.stringify(body, null, 2)}.`);
    return callback(serializationError);
  }
  httpRequest.body = requestContent;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['CardTokenModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get a card.
 *
 * Provides card data. The first six and the last four are included in the
 * response. The ttl values represent the time remaining in seconds until that
 * item is purged. the original card information is not retreivable by the
 * client without the cardvault_raw scope (contact support). If you have the
 * proper scope, use the cardvault/raw/cards endpoint.
 *
 * @param {string} cardToken Card token.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _retrieveCard(cardToken, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let ephemeralKey = (options && options.ephemeralKey !== undefined) ? options.ephemeralKey : undefined;
  // Validate
  try {
    if (cardToken === null || cardToken === undefined || typeof cardToken.valueOf() !== 'string') {
      throw new Error('cardToken cannot be null or undefined and it must be of type string.');
    }
    if (cardToken !== null && cardToken !== undefined) {
      if (cardToken.length > 72)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MaxLength": 72');
      }
      if (cardToken.length < 13)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MinLength": 13');
      }
    }
    if (ephemeralKey !== null && ephemeralKey !== undefined && !(typeof ephemeralKey.valueOf() === 'string' && msRest.isValidUuid(ephemeralKey))) {
      throw new Error('ephemeralKey must be of type string and must be a valid uuid.');
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/cards';
  let queryParameters = [];
  if (ephemeralKey !== null && ephemeralKey !== undefined) {
    queryParameters.push('ephemeralKey=' + encodeURIComponent(ephemeralKey.toString()));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (cardToken !== undefined && cardToken !== null) {
    httpRequest.headers['cardToken'] = cardToken;
  }
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['CardReadModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Delete a card.
 *
 * Returns an empty 204 response on success.
 *
 * @param {string} cardToken Card token.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _deleteCard(cardToken, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (cardToken === null || cardToken === undefined || typeof cardToken.valueOf() !== 'string') {
      throw new Error('cardToken cannot be null or undefined and it must be of type string.');
    }
    if (cardToken !== null && cardToken !== undefined) {
      if (cardToken.length > 72)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MaxLength": 72');
      }
      if (cardToken.length < 13)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MinLength": 13');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/cards';

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'DELETE';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (cardToken !== undefined && cardToken !== null) {
    httpRequest.headers['cardToken'] = cardToken;
  }
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 204 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 204) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Object'
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get a card. Scope cardvault_raw only.
 *
 * Special endpoint to retreive raw card data. It can only be used with the
 * cardvault_raw scope.
 *
 * @param {string} cardToken Card token.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _retrieveRawCard(cardToken, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let ephemeralKey = (options && options.ephemeralKey !== undefined) ? options.ephemeralKey : undefined;
  // Validate
  try {
    if (cardToken === null || cardToken === undefined || typeof cardToken.valueOf() !== 'string') {
      throw new Error('cardToken cannot be null or undefined and it must be of type string.');
    }
    if (cardToken !== null && cardToken !== undefined) {
      if (cardToken.length > 72)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MaxLength": 72');
      }
      if (cardToken.length < 13)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MinLength": 13');
      }
    }
    if (ephemeralKey !== null && ephemeralKey !== undefined && !(typeof ephemeralKey.valueOf() === 'string' && msRest.isValidUuid(ephemeralKey))) {
      throw new Error('ephemeralKey must be of type string and must be a valid uuid.');
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/raw/cards';
  let queryParameters = [];
  if (ephemeralKey !== null && ephemeralKey !== undefined) {
    queryParameters.push('ephemeralKey=' + encodeURIComponent(ephemeralKey.toString()));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (cardToken !== undefined && cardToken !== null) {
    httpRequest.headers['cardToken'] = cardToken;
  }
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['CardModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get an ephemeral key for a specific card token and client.
 *
 * The ephemeralKey is a one time use expiring key that allows an external
 * client to use a card token. The destinationClientId is a valid Enigma Vault
 * clientId of the destination app. The time to live (ttl) is in seconds.
 *
 * @param {string} cardToken Reference to the vaulted card.
 *
 * @param {string} destinationClientId Enigma Vault client granted use of the
 * ephemeralKey.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {number} [options.ttl] Time to live in seconds, max of 1800 seconds.
 * This is only applicable when
 * the card has a ttl of 0 (permanent). Otherwise the ephemeralKey ttl is set
 * to the card ttl.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getCardEphemeralKey(cardToken, destinationClientId, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let ttl = (options && options.ttl !== undefined) ? options.ttl : undefined;
  // Validate
  try {
    if (cardToken === null || cardToken === undefined || typeof cardToken.valueOf() !== 'string') {
      throw new Error('cardToken cannot be null or undefined and it must be of type string.');
    }
    if (cardToken !== null && cardToken !== undefined) {
      if (cardToken.length > 72)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MaxLength": 72');
      }
      if (cardToken.length < 13)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MinLength": 13');
      }
    }
    if (destinationClientId === null || destinationClientId === undefined || typeof destinationClientId.valueOf() !== 'string') {
      throw new Error('destinationClientId cannot be null or undefined and it must be of type string.');
    }
    if (ttl !== null && ttl !== undefined && typeof ttl !== 'number') {
      throw new Error('ttl must be of type number.');
    }
    if (ttl !== null && ttl !== undefined) {
      if (ttl > 1800)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMaximum": 1800');
      }
      if (ttl < 60)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMinimum": 60');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/cards/ephemeralkeys';
  let queryParameters = [];
  queryParameters.push('destinationClientId=' + encodeURIComponent(destinationClientId));
  if (ttl !== null && ttl !== undefined) {
    queryParameters.push('ttl=' + encodeURIComponent(ttl.toString()));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (cardToken !== undefined && cardToken !== null) {
    httpRequest.headers['cardToken'] = cardToken;
  }
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['EphemeralKeyModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get the current ttl of a card.
 *
 * The card's time to live in seconds. Once expired the card is deleted from
 * the vault. If -1, the card lives forever until manually deleted.
 *
 * @param {string} cardToken Card token.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getTtl(cardToken, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let ephemeralKey = (options && options.ephemeralKey !== undefined) ? options.ephemeralKey : undefined;
  // Validate
  try {
    if (cardToken === null || cardToken === undefined || typeof cardToken.valueOf() !== 'string') {
      throw new Error('cardToken cannot be null or undefined and it must be of type string.');
    }
    if (cardToken !== null && cardToken !== undefined) {
      if (cardToken.length > 72)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MaxLength": 72');
      }
      if (cardToken.length < 13)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MinLength": 13');
      }
    }
    if (ephemeralKey !== null && ephemeralKey !== undefined && !(typeof ephemeralKey.valueOf() === 'string' && msRest.isValidUuid(ephemeralKey))) {
      throw new Error('ephemeralKey must be of type string and must be a valid uuid.');
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/cards/ttl';
  let queryParameters = [];
  if (ephemeralKey !== null && ephemeralKey !== undefined) {
    queryParameters.push('ephemeralKey=' + encodeURIComponent(ephemeralKey.toString()));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (cardToken !== undefined && cardToken !== null) {
    httpRequest.headers['cardToken'] = cardToken;
  }
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['CardTtlReadModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Update the card ttl.
 *
 * Adjusts the time (seconds) until deletion. Additional time cannot be added
 * to the CVV's ttl.
 *
 * @param {object} body New card ttl value.
 *
 * @param {number} body.ttl The card's time to live in seconds. Once expired
 * the
 * card is deleted from the vault. If -1, card lives forever until
 * manually deleted.
 *
 * @param {string} cardToken Card token.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _updateCardTtl(body, cardToken, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (body === null || body === undefined) {
      throw new Error('body cannot be null or undefined.');
    }
    if (cardToken === null || cardToken === undefined || typeof cardToken.valueOf() !== 'string') {
      throw new Error('cardToken cannot be null or undefined and it must be of type string.');
    }
    if (cardToken !== null && cardToken !== undefined) {
      if (cardToken.length > 72)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MaxLength": 72');
      }
      if (cardToken.length < 13)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MinLength": 13');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/cards/ttl';

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'PUT';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (cardToken !== undefined && cardToken !== null) {
    httpRequest.headers['cardToken'] = cardToken;
  }
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  // Serialize Request
  let requestContent = null;
  let requestModel = null;
  try {
    if (body !== null && body !== undefined) {
      let requestModelMapper = new client.models['CardTtlModel']().mapper();
      requestModel = client.serialize(requestModelMapper, body, 'body');
      requestContent = JSON.stringify(requestModel);
    }
  } catch (error) {
    let serializationError = new Error(`Error "${error.message}" occurred in serializing the ` +
        `payload - ${JSON.stringify(body, null, 2)}.`);
    return callback(serializationError);
  }
  httpRequest.body = requestContent;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 204 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 204) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Object'
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Send detokenized card data and transaction info to a payment
 * gateway.
 *
 * This endpoint allows you to use a stored card without touching the card
 * data. Build out the request meant for the upstream url and then use the
 * following placeholders to have the endpoint populate them with card data:
 * ${ccn}, ${cvv}, ${fullName}, ${lastName}, ${firstName}, ${cardType}, ${mm},
 * ${yy}, and ${yyyy}. Supports GET/PUT/POST/DELETE.
 *
 * @param {object} body Token and gateway information.
 *
 * @param {string} body.url URL to use on the payment gateway request.
 *
 * @param {string} body.httpMethod HTTP method to use on the payment gateway
 * request.
 *
 * @param {array} [body.headers] Headers to use on the payment gateway request.
 *
 * @param {string} [body.body] Body to use on the payment gateway request.
 *
 * @param {string} cardToken Card token.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _cardProxy(body, cardToken, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let ephemeralKey = (options && options.ephemeralKey !== undefined) ? options.ephemeralKey : undefined;
  // Validate
  try {
    if (body === null || body === undefined) {
      throw new Error('body cannot be null or undefined.');
    }
    if (cardToken === null || cardToken === undefined || typeof cardToken.valueOf() !== 'string') {
      throw new Error('cardToken cannot be null or undefined and it must be of type string.');
    }
    if (cardToken !== null && cardToken !== undefined) {
      if (cardToken.length > 72)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MaxLength": 72');
      }
      if (cardToken.length < 13)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MinLength": 13');
      }
    }
    if (ephemeralKey !== null && ephemeralKey !== undefined && !(typeof ephemeralKey.valueOf() === 'string' && msRest.isValidUuid(ephemeralKey))) {
      throw new Error('ephemeralKey must be of type string and must be a valid uuid.');
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/proxy';
  let queryParameters = [];
  if (ephemeralKey !== null && ephemeralKey !== undefined) {
    queryParameters.push('ephemeralKey=' + encodeURIComponent(ephemeralKey.toString()));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'POST';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (cardToken !== undefined && cardToken !== null) {
    httpRequest.headers['cardToken'] = cardToken;
  }
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  // Serialize Request
  let requestContent = null;
  let requestModel = null;
  try {
    if (body !== null && body !== undefined) {
      let requestModelMapper = new client.models['CardProxyModel']().mapper();
      requestModel = client.serialize(requestModelMapper, body, 'body');
      requestContent = JSON.stringify(requestModel);
    }
  } catch (error) {
    let serializationError = new Error(`Error "${error.message}" occurred in serializing the ` +
        `payload - ${JSON.stringify(body, null, 2)}.`);
    return callback(serializationError);
  }
  httpRequest.body = requestContent;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500 && statusCode !== 503) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['GatewayResponseModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }
    // Deserialize Response
    if (statusCode === 503) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError8 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError8.request = msRest.stripRequest(httpRequest);
        deserializationError8.response = msRest.stripResponse(response);
        return callback(deserializationError8);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get a url to the card processing UI.
 *
 * The card processing UI allows your customers to enter their card data and
 * process upstream with the payment gateway without your app touching it.
 * Build out the request meant for the upstream url and then use the following
 * placeholders to have the endpoint populate them with card data: ${total},
 * ${ccn}, ${cvv}, ${fullName}, ${lastName}, ${firstName}, ${cardType}, ${mm},
 * ${yy}, and ${yyyy}. Supports GET/PUT/POST/DELETE. The customer is redirected
 * back to your app (callback url) via POST with the parameter eVsessionId. You
 * can then use /cardvault/process/sessions/ to determine the adjudication. The
 * session information is available for 72 hours. If the customer choses to
 * save their card, it will be available through the sessions endpoint. If the
 * customer chooses to cancel or if the form timeouts, evException will have a
 * value within the POST callback. For cancels, evException's value will be
 * 'cancel'. For timeouts, the evException's value will be 'timeout'. There are
 * multiple ways to integrate the card process form. You can use it within a
 * popup, redirect or simple iframe.
 *
 * @param {object} body Gateway and cart information.
 *
 * @param {object} body.gatewayRequest
 *
 * @param {string} body.gatewayRequest.url URL to use on the payment gateway
 * request.
 *
 * @param {string} body.gatewayRequest.httpMethod HTTP method to use on the
 * payment gateway request.
 *
 * @param {array} [body.gatewayRequest.headers] Headers to use on the payment
 * gateway request.
 *
 * @param {string} [body.gatewayRequest.body] Body to use on the payment
 * gateway request.
 *
 * @param {object} body.cart
 *
 * @param {string} body.cart.cultureCode ISO 639-1 (language) and ISO 3166-1
 * (country) code.
 *
 * @param {array} body.cart.cartItems List of cart items.
 *
 * @param {number} body.cart.total Total of the cart item amounts. The total is
 * validated against the
 * sum of the cart item amounts.
 *
 * @param {boolean} body.cart.gatewayIntegersOnly Some payment gateways only
 * accept integers. If true, it will multiply
 * the total by 100. For instance, 10.01 will be submitted to the gateway
 * as 1001.
 *
 * @param {string} callbackUrl URL the user is redirected to after storing the
 * card.
 *
 * @param {boolean} showTimer Show or hide the timer.
 *
 * @param {boolean} showCard Show or hide the card visual.
 *
 * @param {number} ttl Form session time to live in seconds. After it expires,
 * the form can no
 * longer be used.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {boolean} [options.preserveFormat] If true, a Luhn passable token is
 * returned consisting of the original first six and last four.
 *
 * @param {string} [options.cardTypes] Card types, comma delimited. Omit for
 * any card.
 * (amex, diners_club_carte_blanche, diners_club_international,
 * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro,
 * uatp, mir).
 *
 * @param {string} [options.pageHeader] Configurable page header.
 *
 * @param {string} [options.submitButtonText] Text of the submit button.
 *
 * @param {string} [options.language] The language to use on the form.
 * Currently en (English), es (Spanish),
 * fr (French), and zh-Hans (Chinese simplified) are available.
 *
 * @param {string} [options.submitButtonColor] The hex color of the submit
 * button.
 *
 * @param {string} [options.cancelButtonColor] The hex color of the cancel
 * button.
 *
 * @param {string} [options.pageColor] The hex color of the page background.
 *
 * @param {string} [options.submitButtonTextColor] The hex color of the submit
 * button text.
 *
 * @param {string} [options.cancelButtonTextColor] The hex color of the cancel
 * button text.
 *
 * @param {string} [options.pageTextColor] The hex color of the page text.
 *
 * @param {string} [options.cartTableBorderColor] The hex color of the cart
 * table header and border.
 *
 * @param {string} [options.cartTableAlternateRowColor] The hex color of the
 * cart table's alternating rows.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getCardProcessForm(body, callbackUrl, showTimer, showCard, ttl, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let preserveFormat = (options && options.preserveFormat !== undefined) ? options.preserveFormat : undefined;
  let cardTypes = (options && options.cardTypes !== undefined) ? options.cardTypes : undefined;
  let pageHeader = (options && options.pageHeader !== undefined) ? options.pageHeader : undefined;
  let submitButtonText = (options && options.submitButtonText !== undefined) ? options.submitButtonText : 'Pay Now';
  let language = (options && options.language !== undefined) ? options.language : 'en';
  let submitButtonColor = (options && options.submitButtonColor !== undefined) ? options.submitButtonColor : '#0078e7';
  let cancelButtonColor = (options && options.cancelButtonColor !== undefined) ? options.cancelButtonColor : '#f08080';
  let pageColor = (options && options.pageColor !== undefined) ? options.pageColor : '#ffffff';
  let submitButtonTextColor = (options && options.submitButtonTextColor !== undefined) ? options.submitButtonTextColor : '#ffffff';
  let cancelButtonTextColor = (options && options.cancelButtonTextColor !== undefined) ? options.cancelButtonTextColor : '#000000';
  let pageTextColor = (options && options.pageTextColor !== undefined) ? options.pageTextColor : '#000000';
  let cartTableBorderColor = (options && options.cartTableBorderColor !== undefined) ? options.cartTableBorderColor : '#e0e0e0';
  let cartTableAlternateRowColor = (options && options.cartTableAlternateRowColor !== undefined) ? options.cartTableAlternateRowColor : '#f2f2f2';
  // Validate
  try {
    if (body === null || body === undefined) {
      throw new Error('body cannot be null or undefined.');
    }
    if (callbackUrl === null || callbackUrl === undefined || typeof callbackUrl.valueOf() !== 'string') {
      throw new Error('callbackUrl cannot be null or undefined and it must be of type string.');
    }
    if (showTimer === null || showTimer === undefined || typeof showTimer !== 'boolean') {
      throw new Error('showTimer cannot be null or undefined and it must be of type boolean.');
    }
    if (showCard === null || showCard === undefined || typeof showCard !== 'boolean') {
      throw new Error('showCard cannot be null or undefined and it must be of type boolean.');
    }
    if (ttl === null || ttl === undefined || typeof ttl !== 'number') {
      throw new Error('ttl cannot be null or undefined and it must be of type number.');
    }
    if (ttl !== null && ttl !== undefined) {
      if (ttl > 1800)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMaximum": 1800');
      }
      if (ttl < 60)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMinimum": 60');
      }
    }
    if (preserveFormat !== null && preserveFormat !== undefined && typeof preserveFormat !== 'boolean') {
      throw new Error('preserveFormat must be of type boolean.');
    }
    if (cardTypes !== null && cardTypes !== undefined && typeof cardTypes.valueOf() !== 'string') {
      throw new Error('cardTypes must be of type string.');
    }
    if (pageHeader !== null && pageHeader !== undefined && typeof pageHeader.valueOf() !== 'string') {
      throw new Error('pageHeader must be of type string.');
    }
    if (pageHeader !== null && pageHeader !== undefined) {
      if (pageHeader.length > 35)
      {
        throw new Error('"pageHeader" should satisfy the constraint - "MaxLength": 35');
      }
      if (pageHeader.length < 3)
      {
        throw new Error('"pageHeader" should satisfy the constraint - "MinLength": 3');
      }
    }
    if (submitButtonText !== null && submitButtonText !== undefined && typeof submitButtonText.valueOf() !== 'string') {
      throw new Error('submitButtonText must be of type string.');
    }
    if (submitButtonText !== null && submitButtonText !== undefined) {
      if (submitButtonText.length > 20)
      {
        throw new Error('"submitButtonText" should satisfy the constraint - "MaxLength": 20');
      }
      if (submitButtonText.length < 0)
      {
        throw new Error('"submitButtonText" should satisfy the constraint - "MinLength": 0');
      }
    }
    if (language !== null && language !== undefined && typeof language.valueOf() !== 'string') {
      throw new Error('language must be of type string.');
    }
    if (language !== null && language !== undefined) {
      if (language.match(/^en|es|fr|zh-Hans$/) === null)
      {
        throw new Error('"language" should satisfy the constraint - "Pattern": /^en|es|fr|zh-Hans$/');
      }
    }
    if (submitButtonColor !== null && submitButtonColor !== undefined && typeof submitButtonColor.valueOf() !== 'string') {
      throw new Error('submitButtonColor must be of type string.');
    }
    if (submitButtonColor !== null && submitButtonColor !== undefined) {
      if (submitButtonColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"submitButtonColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (cancelButtonColor !== null && cancelButtonColor !== undefined && typeof cancelButtonColor.valueOf() !== 'string') {
      throw new Error('cancelButtonColor must be of type string.');
    }
    if (cancelButtonColor !== null && cancelButtonColor !== undefined) {
      if (cancelButtonColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"cancelButtonColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (pageColor !== null && pageColor !== undefined && typeof pageColor.valueOf() !== 'string') {
      throw new Error('pageColor must be of type string.');
    }
    if (pageColor !== null && pageColor !== undefined) {
      if (pageColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"pageColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (submitButtonTextColor !== null && submitButtonTextColor !== undefined && typeof submitButtonTextColor.valueOf() !== 'string') {
      throw new Error('submitButtonTextColor must be of type string.');
    }
    if (submitButtonTextColor !== null && submitButtonTextColor !== undefined) {
      if (submitButtonTextColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"submitButtonTextColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (cancelButtonTextColor !== null && cancelButtonTextColor !== undefined && typeof cancelButtonTextColor.valueOf() !== 'string') {
      throw new Error('cancelButtonTextColor must be of type string.');
    }
    if (cancelButtonTextColor !== null && cancelButtonTextColor !== undefined) {
      if (cancelButtonTextColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"cancelButtonTextColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (pageTextColor !== null && pageTextColor !== undefined && typeof pageTextColor.valueOf() !== 'string') {
      throw new Error('pageTextColor must be of type string.');
    }
    if (pageTextColor !== null && pageTextColor !== undefined) {
      if (pageTextColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"pageTextColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (cartTableBorderColor !== null && cartTableBorderColor !== undefined && typeof cartTableBorderColor.valueOf() !== 'string') {
      throw new Error('cartTableBorderColor must be of type string.');
    }
    if (cartTableBorderColor !== null && cartTableBorderColor !== undefined) {
      if (cartTableBorderColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"cartTableBorderColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (cartTableAlternateRowColor !== null && cartTableAlternateRowColor !== undefined && typeof cartTableAlternateRowColor.valueOf() !== 'string') {
      throw new Error('cartTableAlternateRowColor must be of type string.');
    }
    if (cartTableAlternateRowColor !== null && cartTableAlternateRowColor !== undefined) {
      if (cartTableAlternateRowColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"cartTableAlternateRowColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/process/forms';
  let queryParameters = [];
  queryParameters.push('callbackUrl=' + encodeURIComponent(callbackUrl));
  queryParameters.push('showTimer=' + encodeURIComponent(showTimer.toString()));
  queryParameters.push('showCard=' + encodeURIComponent(showCard.toString()));
  queryParameters.push('ttl=' + encodeURIComponent(ttl.toString()));
  if (preserveFormat !== null && preserveFormat !== undefined) {
    queryParameters.push('preserveFormat=' + encodeURIComponent(preserveFormat.toString()));
  }
  if (cardTypes !== null && cardTypes !== undefined) {
    queryParameters.push('cardTypes=' + encodeURIComponent(cardTypes));
  }
  if (pageHeader !== null && pageHeader !== undefined) {
    queryParameters.push('pageHeader=' + encodeURIComponent(pageHeader));
  }
  if (submitButtonText !== null && submitButtonText !== undefined) {
    queryParameters.push('submitButtonText=' + encodeURIComponent(submitButtonText));
  }
  if (language !== null && language !== undefined) {
    queryParameters.push('language=' + encodeURIComponent(language));
  }
  if (submitButtonColor !== null && submitButtonColor !== undefined) {
    queryParameters.push('submitButtonColor=' + encodeURIComponent(submitButtonColor));
  }
  if (cancelButtonColor !== null && cancelButtonColor !== undefined) {
    queryParameters.push('cancelButtonColor=' + encodeURIComponent(cancelButtonColor));
  }
  if (pageColor !== null && pageColor !== undefined) {
    queryParameters.push('pageColor=' + encodeURIComponent(pageColor));
  }
  if (submitButtonTextColor !== null && submitButtonTextColor !== undefined) {
    queryParameters.push('submitButtonTextColor=' + encodeURIComponent(submitButtonTextColor));
  }
  if (cancelButtonTextColor !== null && cancelButtonTextColor !== undefined) {
    queryParameters.push('cancelButtonTextColor=' + encodeURIComponent(cancelButtonTextColor));
  }
  if (pageTextColor !== null && pageTextColor !== undefined) {
    queryParameters.push('pageTextColor=' + encodeURIComponent(pageTextColor));
  }
  if (cartTableBorderColor !== null && cartTableBorderColor !== undefined) {
    queryParameters.push('cartTableBorderColor=' + encodeURIComponent(cartTableBorderColor));
  }
  if (cartTableAlternateRowColor !== null && cartTableAlternateRowColor !== undefined) {
    queryParameters.push('cartTableAlternateRowColor=' + encodeURIComponent(cartTableAlternateRowColor));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'POST';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  // Serialize Request
  let requestContent = null;
  let requestModel = null;
  try {
    if (body !== null && body !== undefined) {
      let requestModelMapper = new client.models['CardProcessModel']().mapper();
      requestModel = client.serialize(requestModelMapper, body, 'body');
      requestContent = JSON.stringify(requestModel);
    }
  } catch (error) {
    let serializationError = new Error(`Error "${error.message}" occurred in serializing the ` +
        `payload - ${JSON.stringify(body, null, 2)}.`);
    return callback(serializationError);
  }
  httpRequest.body = requestContent;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['CardFormUrlModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get card process session information.
 *
 * Obtain the results from the gateway and retrieve the card token if the
 * customer decided to save it.
 *
 * @param {uuid} id Session ID
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getCardProcessSession(id, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (id === null || id === undefined || typeof id.valueOf() !== 'string' || !msRest.isValidUuid(id)) {
      throw new Error('id cannot be null or undefined and it must be of type string and must be a valid uuid.');
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/process/sessions/{id}';
  requestUrl = requestUrl.replace('{id}', encodeURIComponent(id.toString()));

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['CardGatewayCartResponseModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get a url to the card store UI.
 *
 * The card store form allows your app to store and later use customer card
 * data without touching it. After the cardTtl expires, the card is deleted. If
 * the user decides to save the card, the card is stored permanently. If you're
 * seeking to permanently store the card outside of a transaction (wallet
 * style), set walletSave to true. If you set walletSave to true, the
 * buttonText and cardTtl are overriden. If walletSave is true the CVV isn't
 * requested. If you intend to use the card in a transaction within 30 minutes,
 * set walletSave to false. On callback, your app will receive via POST the
 * card token within the parameter eVtoken. If the customer chooses to cancel
 * or if the form timeouts, the evException parameter will contain the reason.
 * For cancels, evException's value will be 'cancel'. For timeouts,
 * evException's value will be 'timeout'. If embedFormForControl is set to
 * true, pass 'submit' as a message over to the iframe to submit the form. On
 * response, the parent will receive an object that consists of the status, the
 * token, and CardModel object. There are multiple ways to integrate the card
 * store form. You can use it within a popup, redirect, simple iframe, or
 * iframe where the parent page has control to submit the form. You can find
 * example code for the advanced iframe integration on
 * [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).
 *
 * @param {boolean} showTimer Show or hide the timer.
 *
 * @param {boolean} showCard Show or hide the card visual.
 *
 * @param {boolean} walletSave Make true to store the card in your app's
 * wallet. This overrides
 * the cardTtl and buttonText values. The CVV isn't requested if true.
 * If you intend to use the card in a transaction within 30 minutes,
 * set walletSave to false.
 *
 * @param {boolean} embedFormForControl If true, it removes its buttons and
 * any additional padding/spacing, and enables the windows interface for 2-way
 * comms.
 *
 * @param {number} ttl Form session time to live in seconds. After it expires,
 * the form can no
 * longer be used.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {number} [options.cardTtl] The card's time to live in seconds
 * (60-1800 secs).
 * Once expired the card is deleted from the vault. Use the
 * /cardvault/cards/ttl
 * endpoint to extend it. This field is required if walletSave is false.
 *
 * @param {boolean} [options.preserveFormat] If true, a Luhn passable token is
 * returned consisting of the original first six and last four.
 *
 * @param {string} [options.cardTypes] Card types, comma delimited. Omit for
 * any card.
 * (amex, diners_club_carte_blanche, diners_club_international,
 * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro,
 * uatp, mir).
 *
 * @param {string} [options.callbackUrl] URL the user is redirected to after
 * storing the card.
 *
 * @param {string} [options.parentUrl] The parent page URL. The store form uses
 * it when embedFormForControl
 * is true to communicate with the parent window.
 *
 * @param {string} [options.pageHeader] Configurable page header.
 *
 * @param {string} [options.language] The language to use on the form.
 * Currently en (English), es (Spanish),
 * fr (French), and zh-Hans (Chinese simplified) are available.
 *
 * @param {string} [options.submitButtonText] Text of the submit button.
 *
 * @param {string} [options.submitButtonColor] The hex color of the submit
 * button.
 *
 * @param {string} [options.cancelButtonColor] The hex color of the cancel
 * button.
 *
 * @param {string} [options.pageColor] The hex color of the page background.
 *
 * @param {string} [options.submitButtonTextColor] The hex color of the submit
 * button text.
 *
 * @param {string} [options.cancelButtonTextColor] The hex color of the cancel
 * button text.
 *
 * @param {string} [options.pageTextColor] The hex color of the page text.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getCardStoreForm(showTimer, showCard, walletSave, embedFormForControl, ttl, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let cardTtl = (options && options.cardTtl !== undefined) ? options.cardTtl : undefined;
  let preserveFormat = (options && options.preserveFormat !== undefined) ? options.preserveFormat : undefined;
  let cardTypes = (options && options.cardTypes !== undefined) ? options.cardTypes : undefined;
  let callbackUrl = (options && options.callbackUrl !== undefined) ? options.callbackUrl : undefined;
  let parentUrl = (options && options.parentUrl !== undefined) ? options.parentUrl : undefined;
  let pageHeader = (options && options.pageHeader !== undefined) ? options.pageHeader : undefined;
  let language = (options && options.language !== undefined) ? options.language : 'en';
  let submitButtonText = (options && options.submitButtonText !== undefined) ? options.submitButtonText : 'Save';
  let submitButtonColor = (options && options.submitButtonColor !== undefined) ? options.submitButtonColor : '#0078e7';
  let cancelButtonColor = (options && options.cancelButtonColor !== undefined) ? options.cancelButtonColor : '#f08080';
  let pageColor = (options && options.pageColor !== undefined) ? options.pageColor : '#ffffff';
  let submitButtonTextColor = (options && options.submitButtonTextColor !== undefined) ? options.submitButtonTextColor : '#ffffff';
  let cancelButtonTextColor = (options && options.cancelButtonTextColor !== undefined) ? options.cancelButtonTextColor : '#000000';
  let pageTextColor = (options && options.pageTextColor !== undefined) ? options.pageTextColor : '#000000';
  // Validate
  try {
    if (showTimer === null || showTimer === undefined || typeof showTimer !== 'boolean') {
      throw new Error('showTimer cannot be null or undefined and it must be of type boolean.');
    }
    if (showCard === null || showCard === undefined || typeof showCard !== 'boolean') {
      throw new Error('showCard cannot be null or undefined and it must be of type boolean.');
    }
    if (walletSave === null || walletSave === undefined || typeof walletSave !== 'boolean') {
      throw new Error('walletSave cannot be null or undefined and it must be of type boolean.');
    }
    if (embedFormForControl === null || embedFormForControl === undefined || typeof embedFormForControl !== 'boolean') {
      throw new Error('embedFormForControl cannot be null or undefined and it must be of type boolean.');
    }
    if (ttl === null || ttl === undefined || typeof ttl !== 'number') {
      throw new Error('ttl cannot be null or undefined and it must be of type number.');
    }
    if (ttl !== null && ttl !== undefined) {
      if (ttl > 1800)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMaximum": 1800');
      }
      if (ttl < 60)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMinimum": 60');
      }
    }
    if (cardTtl !== null && cardTtl !== undefined && typeof cardTtl !== 'number') {
      throw new Error('cardTtl must be of type number.');
    }
    if (cardTtl !== null && cardTtl !== undefined) {
      if (cardTtl > 1800)
      {
        throw new Error('"cardTtl" should satisfy the constraint - "InclusiveMaximum": 1800');
      }
      if (cardTtl < 60)
      {
        throw new Error('"cardTtl" should satisfy the constraint - "InclusiveMinimum": 60');
      }
    }
    if (preserveFormat !== null && preserveFormat !== undefined && typeof preserveFormat !== 'boolean') {
      throw new Error('preserveFormat must be of type boolean.');
    }
    if (cardTypes !== null && cardTypes !== undefined && typeof cardTypes.valueOf() !== 'string') {
      throw new Error('cardTypes must be of type string.');
    }
    if (callbackUrl !== null && callbackUrl !== undefined && typeof callbackUrl.valueOf() !== 'string') {
      throw new Error('callbackUrl must be of type string.');
    }
    if (parentUrl !== null && parentUrl !== undefined && typeof parentUrl.valueOf() !== 'string') {
      throw new Error('parentUrl must be of type string.');
    }
    if (pageHeader !== null && pageHeader !== undefined && typeof pageHeader.valueOf() !== 'string') {
      throw new Error('pageHeader must be of type string.');
    }
    if (pageHeader !== null && pageHeader !== undefined) {
      if (pageHeader.length > 35)
      {
        throw new Error('"pageHeader" should satisfy the constraint - "MaxLength": 35');
      }
      if (pageHeader.length < 3)
      {
        throw new Error('"pageHeader" should satisfy the constraint - "MinLength": 3');
      }
    }
    if (language !== null && language !== undefined && typeof language.valueOf() !== 'string') {
      throw new Error('language must be of type string.');
    }
    if (language !== null && language !== undefined) {
      if (language.match(/^en|es|fr|zh-Hans$/) === null)
      {
        throw new Error('"language" should satisfy the constraint - "Pattern": /^en|es|fr|zh-Hans$/');
      }
    }
    if (submitButtonText !== null && submitButtonText !== undefined && typeof submitButtonText.valueOf() !== 'string') {
      throw new Error('submitButtonText must be of type string.');
    }
    if (submitButtonText !== null && submitButtonText !== undefined) {
      if (submitButtonText.length > 20)
      {
        throw new Error('"submitButtonText" should satisfy the constraint - "MaxLength": 20');
      }
      if (submitButtonText.length < 0)
      {
        throw new Error('"submitButtonText" should satisfy the constraint - "MinLength": 0');
      }
    }
    if (submitButtonColor !== null && submitButtonColor !== undefined && typeof submitButtonColor.valueOf() !== 'string') {
      throw new Error('submitButtonColor must be of type string.');
    }
    if (submitButtonColor !== null && submitButtonColor !== undefined) {
      if (submitButtonColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"submitButtonColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (cancelButtonColor !== null && cancelButtonColor !== undefined && typeof cancelButtonColor.valueOf() !== 'string') {
      throw new Error('cancelButtonColor must be of type string.');
    }
    if (cancelButtonColor !== null && cancelButtonColor !== undefined) {
      if (cancelButtonColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"cancelButtonColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (pageColor !== null && pageColor !== undefined && typeof pageColor.valueOf() !== 'string') {
      throw new Error('pageColor must be of type string.');
    }
    if (pageColor !== null && pageColor !== undefined) {
      if (pageColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"pageColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (submitButtonTextColor !== null && submitButtonTextColor !== undefined && typeof submitButtonTextColor.valueOf() !== 'string') {
      throw new Error('submitButtonTextColor must be of type string.');
    }
    if (submitButtonTextColor !== null && submitButtonTextColor !== undefined) {
      if (submitButtonTextColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"submitButtonTextColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (cancelButtonTextColor !== null && cancelButtonTextColor !== undefined && typeof cancelButtonTextColor.valueOf() !== 'string') {
      throw new Error('cancelButtonTextColor must be of type string.');
    }
    if (cancelButtonTextColor !== null && cancelButtonTextColor !== undefined) {
      if (cancelButtonTextColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"cancelButtonTextColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (pageTextColor !== null && pageTextColor !== undefined && typeof pageTextColor.valueOf() !== 'string') {
      throw new Error('pageTextColor must be of type string.');
    }
    if (pageTextColor !== null && pageTextColor !== undefined) {
      if (pageTextColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"pageTextColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/store/forms';
  let queryParameters = [];
  queryParameters.push('showTimer=' + encodeURIComponent(showTimer.toString()));
  queryParameters.push('showCard=' + encodeURIComponent(showCard.toString()));
  queryParameters.push('walletSave=' + encodeURIComponent(walletSave.toString()));
  queryParameters.push('embedFormForControl=' + encodeURIComponent(embedFormForControl.toString()));
  queryParameters.push('ttl=' + encodeURIComponent(ttl.toString()));
  if (cardTtl !== null && cardTtl !== undefined) {
    queryParameters.push('cardTtl=' + encodeURIComponent(cardTtl.toString()));
  }
  if (preserveFormat !== null && preserveFormat !== undefined) {
    queryParameters.push('preserveFormat=' + encodeURIComponent(preserveFormat.toString()));
  }
  if (cardTypes !== null && cardTypes !== undefined) {
    queryParameters.push('cardTypes=' + encodeURIComponent(cardTypes));
  }
  if (callbackUrl !== null && callbackUrl !== undefined) {
    queryParameters.push('callbackUrl=' + encodeURIComponent(callbackUrl));
  }
  if (parentUrl !== null && parentUrl !== undefined) {
    queryParameters.push('parentUrl=' + encodeURIComponent(parentUrl));
  }
  if (pageHeader !== null && pageHeader !== undefined) {
    queryParameters.push('pageHeader=' + encodeURIComponent(pageHeader));
  }
  if (language !== null && language !== undefined) {
    queryParameters.push('language=' + encodeURIComponent(language));
  }
  if (submitButtonText !== null && submitButtonText !== undefined) {
    queryParameters.push('submitButtonText=' + encodeURIComponent(submitButtonText));
  }
  if (submitButtonColor !== null && submitButtonColor !== undefined) {
    queryParameters.push('submitButtonColor=' + encodeURIComponent(submitButtonColor));
  }
  if (cancelButtonColor !== null && cancelButtonColor !== undefined) {
    queryParameters.push('cancelButtonColor=' + encodeURIComponent(cancelButtonColor));
  }
  if (pageColor !== null && pageColor !== undefined) {
    queryParameters.push('pageColor=' + encodeURIComponent(pageColor));
  }
  if (submitButtonTextColor !== null && submitButtonTextColor !== undefined) {
    queryParameters.push('submitButtonTextColor=' + encodeURIComponent(submitButtonTextColor));
  }
  if (cancelButtonTextColor !== null && cancelButtonTextColor !== undefined) {
    queryParameters.push('cancelButtonTextColor=' + encodeURIComponent(cancelButtonTextColor));
  }
  if (pageTextColor !== null && pageTextColor !== undefined) {
    queryParameters.push('pageTextColor=' + encodeURIComponent(pageTextColor));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['CardFormUrlModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get a url to the CVV store UI.
 *
 * The CVV store form allows your app to temporarily store the CVV until
 * authorization. The CVV ttl is set to the card's ttl. If the card has a ttl
 * of -1, the CVV ttl will be set to 1800 seconds. If autoSave is true, the
 * callback will not trigger so the client app will need to verify the cvv ttl
 * for its existence. There are multiple ways to integrate the cvv form. You
 * can use it within a popup, redirect, simple iframe, (previous 3 can use
 * autosave) or iframe where the parent page has control to submit the form.
 * You can find example code for the advanced iframe integration on
 * [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).
 *
 * @param {string} cardToken Card token.
 *
 * @param {boolean} showTimer Show or hide the timer.
 *
 * @param {boolean} showCancelButton Show or hide the cancel button.
 *
 * @param {boolean} autoSave If true, the buttons and header are removed, and
 * cvv will be autosaved after user entry.
 * The callback will not trigger so the client app will need to verify the cvv
 * ttl for its existence.
 *
 * @param {boolean} embedFormForControl If true, it removes its buttons and
 * any additional padding/spacing, and enables the windows interface for 2-way
 * comms.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {string} [options.callbackUrl] URL the user is redirected to after
 * storing the card.
 *
 * @param {string} [options.parentUrl] The parent page URL. The store form uses
 * it when embedFormForControl
 * is true to communicate with the parent window.
 *
 * @param {string} [options.pageHeader] Configurable page header.
 *
 * @param {string} [options.language] The language to use on the form.
 * Currently en (English), es (Spanish),
 * fr (French), and zh-Hans (Chinese simplified) are available.
 *
 * @param {string} [options.submitButtonText] Text of the submit button.
 *
 * @param {string} [options.submitButtonColor] The hex color of the submit
 * button.
 *
 * @param {string} [options.cancelButtonColor] The hex color of the cancel
 * button.
 *
 * @param {string} [options.pageColor] The hex color of the page background.
 *
 * @param {string} [options.submitButtonTextColor] The hex color of the submit
 * button text.
 *
 * @param {string} [options.cancelButtonTextColor] The hex color of the cancel
 * button text.
 *
 * @param {string} [options.pageTextColor] The hex color of the page text.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getCvvStoreForm(cardToken, showTimer, showCancelButton, autoSave, embedFormForControl, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let callbackUrl = (options && options.callbackUrl !== undefined) ? options.callbackUrl : undefined;
  let parentUrl = (options && options.parentUrl !== undefined) ? options.parentUrl : undefined;
  let pageHeader = (options && options.pageHeader !== undefined) ? options.pageHeader : undefined;
  let language = (options && options.language !== undefined) ? options.language : 'en';
  let submitButtonText = (options && options.submitButtonText !== undefined) ? options.submitButtonText : 'Submit';
  let submitButtonColor = (options && options.submitButtonColor !== undefined) ? options.submitButtonColor : '#0078e7';
  let cancelButtonColor = (options && options.cancelButtonColor !== undefined) ? options.cancelButtonColor : '#f08080';
  let pageColor = (options && options.pageColor !== undefined) ? options.pageColor : '#ffffff';
  let submitButtonTextColor = (options && options.submitButtonTextColor !== undefined) ? options.submitButtonTextColor : '#ffffff';
  let cancelButtonTextColor = (options && options.cancelButtonTextColor !== undefined) ? options.cancelButtonTextColor : '#000000';
  let pageTextColor = (options && options.pageTextColor !== undefined) ? options.pageTextColor : '#000000';
  // Validate
  try {
    if (cardToken === null || cardToken === undefined || typeof cardToken.valueOf() !== 'string') {
      throw new Error('cardToken cannot be null or undefined and it must be of type string.');
    }
    if (cardToken !== null && cardToken !== undefined) {
      if (cardToken.length > 72)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MaxLength": 72');
      }
      if (cardToken.length < 13)
      {
        throw new Error('"cardToken" should satisfy the constraint - "MinLength": 13');
      }
    }
    if (showTimer === null || showTimer === undefined || typeof showTimer !== 'boolean') {
      throw new Error('showTimer cannot be null or undefined and it must be of type boolean.');
    }
    if (showCancelButton === null || showCancelButton === undefined || typeof showCancelButton !== 'boolean') {
      throw new Error('showCancelButton cannot be null or undefined and it must be of type boolean.');
    }
    if (autoSave === null || autoSave === undefined || typeof autoSave !== 'boolean') {
      throw new Error('autoSave cannot be null or undefined and it must be of type boolean.');
    }
    if (embedFormForControl === null || embedFormForControl === undefined || typeof embedFormForControl !== 'boolean') {
      throw new Error('embedFormForControl cannot be null or undefined and it must be of type boolean.');
    }
    if (callbackUrl !== null && callbackUrl !== undefined && typeof callbackUrl.valueOf() !== 'string') {
      throw new Error('callbackUrl must be of type string.');
    }
    if (parentUrl !== null && parentUrl !== undefined && typeof parentUrl.valueOf() !== 'string') {
      throw new Error('parentUrl must be of type string.');
    }
    if (pageHeader !== null && pageHeader !== undefined && typeof pageHeader.valueOf() !== 'string') {
      throw new Error('pageHeader must be of type string.');
    }
    if (pageHeader !== null && pageHeader !== undefined) {
      if (pageHeader.length > 35)
      {
        throw new Error('"pageHeader" should satisfy the constraint - "MaxLength": 35');
      }
      if (pageHeader.length < 3)
      {
        throw new Error('"pageHeader" should satisfy the constraint - "MinLength": 3');
      }
    }
    if (language !== null && language !== undefined && typeof language.valueOf() !== 'string') {
      throw new Error('language must be of type string.');
    }
    if (language !== null && language !== undefined) {
      if (language.match(/^en|es|fr|zh-Hans$/) === null)
      {
        throw new Error('"language" should satisfy the constraint - "Pattern": /^en|es|fr|zh-Hans$/');
      }
    }
    if (submitButtonText !== null && submitButtonText !== undefined && typeof submitButtonText.valueOf() !== 'string') {
      throw new Error('submitButtonText must be of type string.');
    }
    if (submitButtonText !== null && submitButtonText !== undefined) {
      if (submitButtonText.length > 20)
      {
        throw new Error('"submitButtonText" should satisfy the constraint - "MaxLength": 20');
      }
      if (submitButtonText.length < 0)
      {
        throw new Error('"submitButtonText" should satisfy the constraint - "MinLength": 0');
      }
    }
    if (submitButtonColor !== null && submitButtonColor !== undefined && typeof submitButtonColor.valueOf() !== 'string') {
      throw new Error('submitButtonColor must be of type string.');
    }
    if (submitButtonColor !== null && submitButtonColor !== undefined) {
      if (submitButtonColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"submitButtonColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (cancelButtonColor !== null && cancelButtonColor !== undefined && typeof cancelButtonColor.valueOf() !== 'string') {
      throw new Error('cancelButtonColor must be of type string.');
    }
    if (cancelButtonColor !== null && cancelButtonColor !== undefined) {
      if (cancelButtonColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"cancelButtonColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (pageColor !== null && pageColor !== undefined && typeof pageColor.valueOf() !== 'string') {
      throw new Error('pageColor must be of type string.');
    }
    if (pageColor !== null && pageColor !== undefined) {
      if (pageColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"pageColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (submitButtonTextColor !== null && submitButtonTextColor !== undefined && typeof submitButtonTextColor.valueOf() !== 'string') {
      throw new Error('submitButtonTextColor must be of type string.');
    }
    if (submitButtonTextColor !== null && submitButtonTextColor !== undefined) {
      if (submitButtonTextColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"submitButtonTextColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (cancelButtonTextColor !== null && cancelButtonTextColor !== undefined && typeof cancelButtonTextColor.valueOf() !== 'string') {
      throw new Error('cancelButtonTextColor must be of type string.');
    }
    if (cancelButtonTextColor !== null && cancelButtonTextColor !== undefined) {
      if (cancelButtonTextColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"cancelButtonTextColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (pageTextColor !== null && pageTextColor !== undefined && typeof pageTextColor.valueOf() !== 'string') {
      throw new Error('pageTextColor must be of type string.');
    }
    if (pageTextColor !== null && pageTextColor !== undefined) {
      if (pageTextColor.match(/^#(?:[0-9a-fA-F]{3}){1,2}$/) === null)
      {
        throw new Error('"pageTextColor" should satisfy the constraint - "Pattern": /^#(?:[0-9a-fA-F]{3}){1,2}$/');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/store/cvv/forms';
  let queryParameters = [];
  queryParameters.push('showTimer=' + encodeURIComponent(showTimer.toString()));
  queryParameters.push('showCancelButton=' + encodeURIComponent(showCancelButton.toString()));
  queryParameters.push('autoSave=' + encodeURIComponent(autoSave.toString()));
  queryParameters.push('embedFormForControl=' + encodeURIComponent(embedFormForControl.toString()));
  if (callbackUrl !== null && callbackUrl !== undefined) {
    queryParameters.push('callbackUrl=' + encodeURIComponent(callbackUrl));
  }
  if (parentUrl !== null && parentUrl !== undefined) {
    queryParameters.push('parentUrl=' + encodeURIComponent(parentUrl));
  }
  if (pageHeader !== null && pageHeader !== undefined) {
    queryParameters.push('pageHeader=' + encodeURIComponent(pageHeader));
  }
  if (language !== null && language !== undefined) {
    queryParameters.push('language=' + encodeURIComponent(language));
  }
  if (submitButtonText !== null && submitButtonText !== undefined) {
    queryParameters.push('submitButtonText=' + encodeURIComponent(submitButtonText));
  }
  if (submitButtonColor !== null && submitButtonColor !== undefined) {
    queryParameters.push('submitButtonColor=' + encodeURIComponent(submitButtonColor));
  }
  if (cancelButtonColor !== null && cancelButtonColor !== undefined) {
    queryParameters.push('cancelButtonColor=' + encodeURIComponent(cancelButtonColor));
  }
  if (pageColor !== null && pageColor !== undefined) {
    queryParameters.push('pageColor=' + encodeURIComponent(pageColor));
  }
  if (submitButtonTextColor !== null && submitButtonTextColor !== undefined) {
    queryParameters.push('submitButtonTextColor=' + encodeURIComponent(submitButtonTextColor));
  }
  if (cancelButtonTextColor !== null && cancelButtonTextColor !== undefined) {
    queryParameters.push('cancelButtonTextColor=' + encodeURIComponent(cancelButtonTextColor));
  }
  if (pageTextColor !== null && pageTextColor !== undefined) {
    queryParameters.push('pageTextColor=' + encodeURIComponent(pageTextColor));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (cardToken !== undefined && cardToken !== null) {
    httpRequest.headers['cardToken'] = cardToken;
  }
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['CardFormUrlModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get a listing of all supported cultures and currencies.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {string} [options.cultureCode] ISO 639-1 (language) and ISO 3166-1
 * (country) code.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getCultures(xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let cultureCode = (options && options.cultureCode !== undefined) ? options.cultureCode : undefined;
  // Validate
  try {
    if (cultureCode !== null && cultureCode !== undefined && typeof cultureCode.valueOf() !== 'string') {
      throw new Error('cultureCode must be of type string.');
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'cardvault/references/cultures';
  let queryParameters = [];
  if (cultureCode !== null && cultureCode !== undefined) {
    queryParameters.push('cultureCode=' + encodeURIComponent(cultureCode));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'CultureModelElementType',
                  type: {
                    name: 'Composite',
                    className: 'CultureModel'
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Store a secret.
 *
 * Supports up to 5,000 plaintext objects per request. Plaintext strings must
 * be less than 1000 characters in length. The customIdentifier attribute ties
 * your unencrypted data to the tokens. The customIdentifier is not stored
 * within the vault.
 *
 * @param {array} body Your secrets to vault.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _storeDataSecrets(body, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'datavault/secrets';

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'POST';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  // Serialize Request
  let requestContent = null;
  let requestModel = null;
  try {
    if (body !== null && body !== undefined) {
      let requestModelMapper = {
        required: true,
        serializedName: 'body',
        type: {
          name: 'Sequence',
          element: {
              required: false,
              serializedName: 'PlaintextCustomerIdentifierModelElementType',
              type: {
                name: 'Composite',
                className: 'PlaintextCustomerIdentifierModel'
              }
          }
        }
      };
      requestModel = client.serialize(requestModelMapper, body, 'body');
      requestContent = JSON.stringify(requestModel);
    }
  } catch (error) {
    let serializationError = new Error(`Error "${error.message}" occurred in serializing the ` +
        `payload - ${JSON.stringify(body, null, 2)}.`);
    return callback(serializationError);
  }
  httpRequest.body = requestContent;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'TokenCustomIdentifierModelElementType',
                  type: {
                    name: 'Composite',
                    className: 'TokenCustomIdentifierModel'
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get a secret by token.
 *
 * The ephemeralKey is a one time use expiring key that allows an external
 * client to obtain the token's secret. To generate one, use the
 * datavault/secrets/ephemeralKey endpoint.
 *
 * @param {string} token Reference to the vaulted secret.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {uuid} [options.ephemeralKey] One time use expiring key.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getDataSecret(token, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let ephemeralKey = (options && options.ephemeralKey !== undefined) ? options.ephemeralKey : undefined;
  // Validate
  try {
    if (token === null || token === undefined || typeof token.valueOf() !== 'string') {
      throw new Error('token cannot be null or undefined and it must be of type string.');
    }
    if (token !== null && token !== undefined) {
      if (token.length > 72)
      {
        throw new Error('"token" should satisfy the constraint - "MaxLength": 72');
      }
      if (token.length < 72)
      {
        throw new Error('"token" should satisfy the constraint - "MinLength": 72');
      }
    }
    if (ephemeralKey !== null && ephemeralKey !== undefined && !(typeof ephemeralKey.valueOf() === 'string' && msRest.isValidUuid(ephemeralKey))) {
      throw new Error('ephemeralKey must be of type string and must be a valid uuid.');
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'datavault/secrets/{token}';
  requestUrl = requestUrl.replace('{token}', encodeURIComponent(token));
  let queryParameters = [];
  if (ephemeralKey !== null && ephemeralKey !== undefined) {
    queryParameters.push('ephemeralKey=' + encodeURIComponent(ephemeralKey.toString()));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['PlaintextModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Delete a secret.
 *
 * @param {string} token Reference to the vaulted secret.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _deleteDataSecret(token, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (token === null || token === undefined || typeof token.valueOf() !== 'string') {
      throw new Error('token cannot be null or undefined and it must be of type string.');
    }
    if (token !== null && token !== undefined) {
      if (token.length > 72)
      {
        throw new Error('"token" should satisfy the constraint - "MaxLength": 72');
      }
      if (token.length < 72)
      {
        throw new Error('"token" should satisfy the constraint - "MinLength": 72');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'datavault/secrets/{token}';
  requestUrl = requestUrl.replace('{token}', encodeURIComponent(token));

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'DELETE';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 204 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 204) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Object'
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Search by plaintext.
 *
 * Exact matches will only be returned and is case sensitive.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.body] Text to search within the vault. Exact
 * matches will only be returned and is case sensitive.
 *
 * @param {string} options.body.plaintext Secret text.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _searchDataSecrets(xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let body = (options && options.body !== undefined) ? options.body : undefined;
  // Validate
  try {
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'datavault/search';

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'POST';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  // Serialize Request
  let requestContent = null;
  let requestModel = null;
  try {
    if (body !== null && body !== undefined) {
      let requestModelMapper = new client.models['PlaintextModel']().mapper();
      requestModel = client.serialize(requestModelMapper, body, 'body');
      requestContent = JSON.stringify(requestModel);
    }
  } catch (error) {
    let serializationError = new Error(`Error "${error.message}" occurred in serializing the ` +
        `payload - ${JSON.stringify(body, null, 2)}.`);
    return callback(serializationError);
  }
  httpRequest.body = requestContent;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'TokenModelElementType',
                  type: {
                    name: 'Composite',
                    className: 'TokenModel'
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get an ephemeral key for a specific token and client.
 *
 * The ephemeralKey is a one time use expiring key that allows an external
 * client to obtain the token's secret. The destinationClientId is a valid
 * Enigma Vault clientId of the destination app. The time to live (ttl) is in
 * seconds.
 *
 * @param {string} token Reference to the vaulted secret.
 *
 * @param {string} destinationClientId Enigma Vault client granted use of the
 * ephemeralKey.
 *
 * @param {number} ttl Time to live in seconds, max of 300.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getDataEphemeralKey(token, destinationClientId, ttl, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (token === null || token === undefined || typeof token.valueOf() !== 'string') {
      throw new Error('token cannot be null or undefined and it must be of type string.');
    }
    if (token !== null && token !== undefined) {
      if (token.length > 72)
      {
        throw new Error('"token" should satisfy the constraint - "MaxLength": 72');
      }
      if (token.length < 72)
      {
        throw new Error('"token" should satisfy the constraint - "MinLength": 72');
      }
    }
    if (destinationClientId === null || destinationClientId === undefined || typeof destinationClientId.valueOf() !== 'string') {
      throw new Error('destinationClientId cannot be null or undefined and it must be of type string.');
    }
    if (ttl === null || ttl === undefined || typeof ttl !== 'number') {
      throw new Error('ttl cannot be null or undefined and it must be of type number.');
    }
    if (ttl !== null && ttl !== undefined) {
      if (ttl > 300)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMaximum": 300');
      }
      if (ttl < 1)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMinimum": 1');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'datavault/ephemeralkeys/{token}';
  requestUrl = requestUrl.replace('{token}', encodeURIComponent(token));
  let queryParameters = [];
  queryParameters.push('destinationClientId=' + encodeURIComponent(destinationClientId));
  queryParameters.push('ttl=' + encodeURIComponent(ttl.toString()));
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['EphemeralKeyModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get a url to upload a file.
 *
 * The url is used to upload (PUT) a file into the vault. The url has an
 * exipration of five minutes. The file size cannot exceed 5 gigabytes. A
 * websocket url is provided so that the status of the file can be tracked in
 * realtime.
 *
 * @param {string} contentType The MIME type associated with the file.
 *
 * @param {string} fileExtension The file extension without the leading .
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getUploadUrl(contentType, fileExtension, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (contentType === null || contentType === undefined || typeof contentType.valueOf() !== 'string') {
      throw new Error('contentType cannot be null or undefined and it must be of type string.');
    }
    if (contentType !== null && contentType !== undefined) {
      if (contentType.length > 255)
      {
        throw new Error('"contentType" should satisfy the constraint - "MaxLength": 255');
      }
      if (contentType.length < 3)
      {
        throw new Error('"contentType" should satisfy the constraint - "MinLength": 3');
      }
    }
    if (fileExtension === null || fileExtension === undefined || typeof fileExtension.valueOf() !== 'string') {
      throw new Error('fileExtension cannot be null or undefined and it must be of type string.');
    }
    if (fileExtension !== null && fileExtension !== undefined) {
      if (fileExtension.match(/^[0-9a-zA-Z]{1,10}$/) === null)
      {
        throw new Error('"fileExtension" should satisfy the constraint - "Pattern": /^[0-9a-zA-Z]{1,10}$/');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'filevault/uploadurls';
  let queryParameters = [];
  queryParameters.push('contentType=' + encodeURIComponent(contentType));
  queryParameters.push('fileExtension=' + encodeURIComponent(fileExtension));
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['UploadUrlModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get the status of a file.
 *
 * This endpoint has been deprecated because the file status is now provided
 * through a websocket API.
 *
 * @param {string} fileName Tokenized file name.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getFileStatus(fileName, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (fileName === null || fileName === undefined || typeof fileName.valueOf() !== 'string') {
      throw new Error('fileName cannot be null or undefined and it must be of type string.');
    }
    if (fileName !== null && fileName !== undefined) {
      if (fileName.match(/^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$/) === null)
      {
        throw new Error('"fileName" should satisfy the constraint - "Pattern": /^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$/');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'filevault/statuses/{fileName}';
  requestUrl = requestUrl.replace('{fileName}', encodeURIComponent(fileName));

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['FileStatusModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get a url to decrypt and download the file.
 *
 * The url is used to download the file out of the vault. The url has an
 * exipration of five minutes. When aSync is set to true for large files, a
 * websocket API url is returned so that the file status can be monitored in
 * real time. When the file is finished decrypting, the download url is
 * provided through the websocket connection.
 *
 * @param {string} fileName Tokenized file name.
 *
 * @param {boolean} aSync Set to true to decrypt large files; you'll use the
 * websocket API for notifications.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {uuid} [options.ephemeralKey] One time use expiring key.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getDownloadUrl(fileName, aSync, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  let ephemeralKey = (options && options.ephemeralKey !== undefined) ? options.ephemeralKey : undefined;
  // Validate
  try {
    if (fileName === null || fileName === undefined || typeof fileName.valueOf() !== 'string') {
      throw new Error('fileName cannot be null or undefined and it must be of type string.');
    }
    if (fileName !== null && fileName !== undefined) {
      if (fileName.match(/^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$/) === null)
      {
        throw new Error('"fileName" should satisfy the constraint - "Pattern": /^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$/');
      }
    }
    if (aSync === null || aSync === undefined || typeof aSync !== 'boolean') {
      throw new Error('aSync cannot be null or undefined and it must be of type boolean.');
    }
    if (ephemeralKey !== null && ephemeralKey !== undefined && !(typeof ephemeralKey.valueOf() === 'string' && msRest.isValidUuid(ephemeralKey))) {
      throw new Error('ephemeralKey must be of type string and must be a valid uuid.');
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'filevault/downloadurls/{fileName}';
  requestUrl = requestUrl.replace('{fileName}', encodeURIComponent(fileName));
  let queryParameters = [];
  queryParameters.push('aSync=' + encodeURIComponent(aSync.toString()));
  if (ephemeralKey !== null && ephemeralKey !== undefined) {
    queryParameters.push('ephemeralKey=' + encodeURIComponent(ephemeralKey.toString()));
  }
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 202 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 409 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['DownloadUrlModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 202) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['WsUrlModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 409) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError8 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError8.request = msRest.stripRequest(httpRequest);
        deserializationError8.response = msRest.stripResponse(response);
        return callback(deserializationError8);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError9 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError9.request = msRest.stripRequest(httpRequest);
        deserializationError9.response = msRest.stripResponse(response);
        return callback(deserializationError9);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Delete a file.
 *
 * On successful deletion, a 204 response is returned.
 *
 * @param {string} fileName Tokenized file name.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _deleteFile(fileName, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (fileName === null || fileName === undefined || typeof fileName.valueOf() !== 'string') {
      throw new Error('fileName cannot be null or undefined and it must be of type string.');
    }
    if (fileName !== null && fileName !== undefined) {
      if (fileName.match(/^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$/) === null)
      {
        throw new Error('"fileName" should satisfy the constraint - "Pattern": /^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$/');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'filevault/files/{fileName}';
  requestUrl = requestUrl.replace('{fileName}', encodeURIComponent(fileName));

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'DELETE';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 204 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/**
 * @summary Get an ephemeral key for a specific fileName and client.
 *
 * The ephemeralKey is a one time use expiring key that allows an external
 * client to obtain a download url. The destinationClientId is a valid Enigma
 * Vault clientId of the destination app. The time to live (ttl) is in seconds.
 *
 * @param {string} fileName Tokenized file name.
 *
 * @param {string} destinationClientId Enigma Vault client granted use of the
 * ephemeralKey.
 *
 * @param {number} ttl Time to live in seconds, max of 300.
 *
 * @param {string} xApiVersion The requested API version
 *
 * @param {object} [options] Optional Parameters.
 *
 * @param {object} [options.customHeaders] Headers that will be added to the
 * request
 *
 * @param {function} callback - The callback.
 *
 * @returns {function} callback(err, result, request, response)
 *
 *                      {Error}  err        - The Error object if an error occurred, null otherwise.
 *
 *                      {object} [result]   - The deserialized result object if an error did not occur.
 *
 *                      {object} [request]  - The HTTP Request object if an error did not occur.
 *
 *                      {stream} [response] - The HTTP Response stream if an error did not occur.
 */
function _getFileEphemeralKey(fileName, destinationClientId, ttl, xApiVersion, options, callback) {
   /* jshint validthis: true */
  let client = this;
  if(!callback && typeof options === 'function') {
    callback = options;
    options = null;
  }
  if (!callback) {
    throw new Error('callback cannot be null.');
  }
  // Validate
  try {
    if (fileName === null || fileName === undefined || typeof fileName.valueOf() !== 'string') {
      throw new Error('fileName cannot be null or undefined and it must be of type string.');
    }
    if (fileName !== null && fileName !== undefined) {
      if (fileName.match(/^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$/) === null)
      {
        throw new Error('"fileName" should satisfy the constraint - "Pattern": /^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$/');
      }
    }
    if (destinationClientId === null || destinationClientId === undefined || typeof destinationClientId.valueOf() !== 'string') {
      throw new Error('destinationClientId cannot be null or undefined and it must be of type string.');
    }
    if (ttl === null || ttl === undefined || typeof ttl !== 'number') {
      throw new Error('ttl cannot be null or undefined and it must be of type number.');
    }
    if (ttl !== null && ttl !== undefined) {
      if (ttl > 300)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMaximum": 300');
      }
      if (ttl < 1)
      {
        throw new Error('"ttl" should satisfy the constraint - "InclusiveMinimum": 1');
      }
    }
    if (xApiVersion === null || xApiVersion === undefined || typeof xApiVersion.valueOf() !== 'string') {
      throw new Error('xApiVersion cannot be null or undefined and it must be of type string.');
    }
  } catch (error) {
    return callback(error);
  }

  // Construct URL
  let baseUrl = this.baseUri;
  let requestUrl = baseUrl + (baseUrl.endsWith('/') ? '' : '/') + 'filevault/ephemeralkeys/{fileName}';
  requestUrl = requestUrl.replace('{fileName}', encodeURIComponent(fileName));
  let queryParameters = [];
  queryParameters.push('destinationClientId=' + encodeURIComponent(destinationClientId));
  queryParameters.push('ttl=' + encodeURIComponent(ttl.toString()));
  if (queryParameters.length > 0) {
    requestUrl += '?' + queryParameters.join('&');
  }

  // Create HTTP transport objects
  let httpRequest = new WebResource();
  httpRequest.method = 'GET';
  httpRequest.url = requestUrl;
  httpRequest.headers = {};
  // Set Headers
  httpRequest.headers['Content-Type'] = 'application/json; charset=utf-8';
  if (xApiVersion !== undefined && xApiVersion !== null) {
    httpRequest.headers['x-api-version'] = xApiVersion;
  }
  if(options) {
    for(let headerName in options['customHeaders']) {
      if (options['customHeaders'].hasOwnProperty(headerName)) {
        httpRequest.headers[headerName] = options['customHeaders'][headerName];
      }
    }
  }
  httpRequest.body = null;
  // Send Request
  return client.pipeline(httpRequest, (err, response, responseBody) => {
    if (err) {
      return callback(err);
    }
    let statusCode = response.statusCode;
    if (statusCode !== 200 && statusCode !== 400 && statusCode !== 401 && statusCode !== 403 && statusCode !== 404 && statusCode !== 413 && statusCode !== 415 && statusCode !== 500) {
      let error = new Error(responseBody);
      error.statusCode = response.statusCode;
      error.request = msRest.stripRequest(httpRequest);
      error.response = msRest.stripResponse(response);
      if (responseBody === '') responseBody = null;
      let parsedErrorResponse;
      try {
        parsedErrorResponse = JSON.parse(responseBody);
        if (parsedErrorResponse) {
          let internalError = null;
          if (parsedErrorResponse.error) internalError = parsedErrorResponse.error;
          error.code = internalError ? internalError.code : parsedErrorResponse.code;
          error.message = internalError ? internalError.message : parsedErrorResponse.message;
        }
      } catch (defaultError) {
        error.message = `Error "${defaultError.message}" occurred in deserializing the responseBody ` +
                         `- "${responseBody}" for the default response.`;
        return callback(error);
      }
      return callback(error);
    }
    // Create Result
    let result = null;
    if (responseBody === '') responseBody = null;
    // Deserialize Response
    if (statusCode === 200) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['EphemeralKeyModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError.request = msRest.stripRequest(httpRequest);
        deserializationError.response = msRest.stripResponse(response);
        return callback(deserializationError);
      }
    }
    // Deserialize Response
    if (statusCode === 400) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = {
            required: false,
            serializedName: 'parsedResponse',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'ArrayElementType',
                  type: {
                    name: 'Sequence',
                    element: {
                        required: false,
                        serializedName: 'StringElementType',
                        type: {
                          name: 'String'
                        }
                    }
                  }
              }
            }
          };
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError1 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError1.request = msRest.stripRequest(httpRequest);
        deserializationError1.response = msRest.stripResponse(response);
        return callback(deserializationError1);
      }
    }
    // Deserialize Response
    if (statusCode === 401) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError2 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError2.request = msRest.stripRequest(httpRequest);
        deserializationError2.response = msRest.stripResponse(response);
        return callback(deserializationError2);
      }
    }
    // Deserialize Response
    if (statusCode === 403) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError3 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError3.request = msRest.stripRequest(httpRequest);
        deserializationError3.response = msRest.stripResponse(response);
        return callback(deserializationError3);
      }
    }
    // Deserialize Response
    if (statusCode === 404) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError4 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError4.request = msRest.stripRequest(httpRequest);
        deserializationError4.response = msRest.stripResponse(response);
        return callback(deserializationError4);
      }
    }
    // Deserialize Response
    if (statusCode === 413) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError5 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError5.request = msRest.stripRequest(httpRequest);
        deserializationError5.response = msRest.stripResponse(response);
        return callback(deserializationError5);
      }
    }
    // Deserialize Response
    if (statusCode === 415) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ClientErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError6 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError6.request = msRest.stripRequest(httpRequest);
        deserializationError6.response = msRest.stripResponse(response);
        return callback(deserializationError6);
      }
    }
    // Deserialize Response
    if (statusCode === 500) {
      let parsedResponse = null;
      try {
        parsedResponse = JSON.parse(responseBody);
        result = JSON.parse(responseBody);
        if (parsedResponse !== null && parsedResponse !== undefined) {
          let resultMapper = new client.models['ServerErrorModel']().mapper();
          result = client.deserialize(resultMapper, parsedResponse, 'result');
        }
      } catch (error) {
        let deserializationError7 = new Error(`Error ${error} occurred in deserializing the responseBody - ${responseBody}`);
        deserializationError7.request = msRest.stripRequest(httpRequest);
        deserializationError7.response = msRest.stripResponse(response);
        return callback(deserializationError7);
      }
    }

    return callback(null, result, httpRequest, response);
  });
}

/** Class representing a EnigmaVaultAPI. */
class EnigmaVaultAPI extends ServiceClient {
  /**
   * Create a EnigmaVaultAPI.
   * @param {credentials} credentials - Subscription credentials which uniquely identify client subscription.
   * @param {string} [baseUri] - The base URI of the service.
   * @param {object} [options] - The parameter options
   * @param {Array} [options.filters] - Filters to be added to the request pipeline
   * @param {object} [options.requestOptions] - Options for the underlying request object
   * {@link https://github.com/request/request#requestoptions-callback Options doc}
   * @param {boolean} [options.noRetryPolicy] - If set to true, turn off default retry policy
   */
  constructor(credentials, baseUri, options) {
    if (credentials === null || credentials === undefined) {
      throw new Error('\'credentials\' cannot be null.');
    }

    if (!options) options = {};

    super(credentials, options);

    this.baseUri = baseUri;
    if (!this.baseUri) {
      this.baseUri = 'http://localhost';
    }
    this.credentials = credentials;

    let packageInfo = this.getPackageJsonInfo(__dirname);
    this.addUserAgentInfo(`${packageInfo.name}/${packageInfo.version}`);
    this.models = models;
    this._storeCard = _storeCard;
    this._retrieveCard = _retrieveCard;
    this._deleteCard = _deleteCard;
    this._retrieveRawCard = _retrieveRawCard;
    this._getCardEphemeralKey = _getCardEphemeralKey;
    this._getTtl = _getTtl;
    this._updateCardTtl = _updateCardTtl;
    this._cardProxy = _cardProxy;
    this._getCardProcessForm = _getCardProcessForm;
    this._getCardProcessSession = _getCardProcessSession;
    this._getCardStoreForm = _getCardStoreForm;
    this._getCvvStoreForm = _getCvvStoreForm;
    this._getCultures = _getCultures;
    this._storeDataSecrets = _storeDataSecrets;
    this._getDataSecret = _getDataSecret;
    this._deleteDataSecret = _deleteDataSecret;
    this._searchDataSecrets = _searchDataSecrets;
    this._getDataEphemeralKey = _getDataEphemeralKey;
    this._getUploadUrl = _getUploadUrl;
    this._getFileStatus = _getFileStatus;
    this._getDownloadUrl = _getDownloadUrl;
    this._deleteFile = _deleteFile;
    this._getFileEphemeralKey = _getFileEphemeralKey;
    msRest.addSerializationMixin(this);
  }

  /**
   * @summary Store a card.
   *
   * When a card is stored in the vault, the original card information is not
   * retrievable by the client without the cardvault_raw scope (contact support).
   * The CVV's ttl is set to the same ttl as the card unless the card is stored
   * permanently. If the card is stored permanently, the CVV's ttl is set to 30
   * minutes. The CVV is purged after its first use or after its ttl expires,
   * whichever comes first. After the card's ttl, the card is deleted. To make
   * the card permanent, leave out the ttl property. The full card number can be
   * used through the proxy endpoint. You can get the first six, the last four,
   * full name, and expiration from /cardvault/cards (GET).
   *
   * @param {object} body Card information.
   *
   * @param {string} body.ccn Card number.
   *
   * @param {string} body.fullName Full name located on the card.
   *
   * @param {number} body.expMonth Expiration month.
   *
   * @param {number} body.expYear Expiration year.
   *
   * @param {string} [body.cvv] Card verification value (security code). This
   * value is not stored permanently.
   *
   * @param {string} body.cardType Type of card (amex, diners_club_carte_blanche,
   * diners_club_international,
   * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro,
   * uatp, mir).
   *
   * @param {number} body.cvvTtl Remaining ttl before the CVV gets deleted.
   *
   * @param {number} [body.ttl] The card's time to live in seconds. Once expired
   * the
   * card is deleted from the vault.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {boolean} [options.preserveFormat] If true, a Luhn passable token is
   * returned consisting of the original first six and last four.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  storeCardWithHttpOperationResponse(body, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._storeCard(body, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Store a card.
   *
   * When a card is stored in the vault, the original card information is not
   * retrievable by the client without the cardvault_raw scope (contact support).
   * The CVV's ttl is set to the same ttl as the card unless the card is stored
   * permanently. If the card is stored permanently, the CVV's ttl is set to 30
   * minutes. The CVV is purged after its first use or after its ttl expires,
   * whichever comes first. After the card's ttl, the card is deleted. To make
   * the card permanent, leave out the ttl property. The full card number can be
   * used through the proxy endpoint. You can get the first six, the last four,
   * full name, and expiration from /cardvault/cards (GET).
   *
   * @param {object} body Card information.
   *
   * @param {string} body.ccn Card number.
   *
   * @param {string} body.fullName Full name located on the card.
   *
   * @param {number} body.expMonth Expiration month.
   *
   * @param {number} body.expYear Expiration year.
   *
   * @param {string} [body.cvv] Card verification value (security code). This
   * value is not stored permanently.
   *
   * @param {string} body.cardType Type of card (amex, diners_club_carte_blanche,
   * diners_club_international,
   * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro,
   * uatp, mir).
   *
   * @param {number} body.cvvTtl Remaining ttl before the CVV gets deleted.
   *
   * @param {number} [body.ttl] The card's time to live in seconds. Once expired
   * the
   * card is deleted from the vault.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {boolean} [options.preserveFormat] If true, a Luhn passable token is
   * returned consisting of the original first six and last four.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  storeCard(body, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._storeCard(body, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._storeCard(body, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get a card.
   *
   * Provides card data. The first six and the last four are included in the
   * response. The ttl values represent the time remaining in seconds until that
   * item is purged. the original card information is not retreivable by the
   * client without the cardvault_raw scope (contact support). If you have the
   * proper scope, use the cardvault/raw/cards endpoint.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  retrieveCardWithHttpOperationResponse(cardToken, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._retrieveCard(cardToken, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get a card.
   *
   * Provides card data. The first six and the last four are included in the
   * response. The ttl values represent the time remaining in seconds until that
   * item is purged. the original card information is not retreivable by the
   * client without the cardvault_raw scope (contact support). If you have the
   * proper scope, use the cardvault/raw/cards endpoint.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  retrieveCard(cardToken, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._retrieveCard(cardToken, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._retrieveCard(cardToken, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Delete a card.
   *
   * Returns an empty 204 response on success.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  deleteCardWithHttpOperationResponse(cardToken, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._deleteCard(cardToken, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Delete a card.
   *
   * Returns an empty 204 response on success.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  deleteCard(cardToken, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._deleteCard(cardToken, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._deleteCard(cardToken, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get a card. Scope cardvault_raw only.
   *
   * Special endpoint to retreive raw card data. It can only be used with the
   * cardvault_raw scope.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  retrieveRawCardWithHttpOperationResponse(cardToken, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._retrieveRawCard(cardToken, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get a card. Scope cardvault_raw only.
   *
   * Special endpoint to retreive raw card data. It can only be used with the
   * cardvault_raw scope.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  retrieveRawCard(cardToken, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._retrieveRawCard(cardToken, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._retrieveRawCard(cardToken, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get an ephemeral key for a specific card token and client.
   *
   * The ephemeralKey is a one time use expiring key that allows an external
   * client to use a card token. The destinationClientId is a valid Enigma Vault
   * clientId of the destination app. The time to live (ttl) is in seconds.
   *
   * @param {string} cardToken Reference to the vaulted card.
   *
   * @param {string} destinationClientId Enigma Vault client granted use of the
   * ephemeralKey.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {number} [options.ttl] Time to live in seconds, max of 1800 seconds.
   * This is only applicable when
   * the card has a ttl of 0 (permanent). Otherwise the ephemeralKey ttl is set
   * to the card ttl.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getCardEphemeralKeyWithHttpOperationResponse(cardToken, destinationClientId, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getCardEphemeralKey(cardToken, destinationClientId, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get an ephemeral key for a specific card token and client.
   *
   * The ephemeralKey is a one time use expiring key that allows an external
   * client to use a card token. The destinationClientId is a valid Enigma Vault
   * clientId of the destination app. The time to live (ttl) is in seconds.
   *
   * @param {string} cardToken Reference to the vaulted card.
   *
   * @param {string} destinationClientId Enigma Vault client granted use of the
   * ephemeralKey.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {number} [options.ttl] Time to live in seconds, max of 1800 seconds.
   * This is only applicable when
   * the card has a ttl of 0 (permanent). Otherwise the ephemeralKey ttl is set
   * to the card ttl.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getCardEphemeralKey(cardToken, destinationClientId, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getCardEphemeralKey(cardToken, destinationClientId, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getCardEphemeralKey(cardToken, destinationClientId, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get the current ttl of a card.
   *
   * The card's time to live in seconds. Once expired the card is deleted from
   * the vault. If -1, the card lives forever until manually deleted.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getTtlWithHttpOperationResponse(cardToken, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getTtl(cardToken, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get the current ttl of a card.
   *
   * The card's time to live in seconds. Once expired the card is deleted from
   * the vault. If -1, the card lives forever until manually deleted.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getTtl(cardToken, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getTtl(cardToken, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getTtl(cardToken, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Update the card ttl.
   *
   * Adjusts the time (seconds) until deletion. Additional time cannot be added
   * to the CVV's ttl.
   *
   * @param {object} body New card ttl value.
   *
   * @param {number} body.ttl The card's time to live in seconds. Once expired
   * the
   * card is deleted from the vault. If -1, card lives forever until
   * manually deleted.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  updateCardTtlWithHttpOperationResponse(body, cardToken, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._updateCardTtl(body, cardToken, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Update the card ttl.
   *
   * Adjusts the time (seconds) until deletion. Additional time cannot be added
   * to the CVV's ttl.
   *
   * @param {object} body New card ttl value.
   *
   * @param {number} body.ttl The card's time to live in seconds. Once expired
   * the
   * card is deleted from the vault. If -1, card lives forever until
   * manually deleted.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  updateCardTtl(body, cardToken, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._updateCardTtl(body, cardToken, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._updateCardTtl(body, cardToken, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Send detokenized card data and transaction info to a payment
   * gateway.
   *
   * This endpoint allows you to use a stored card without touching the card
   * data. Build out the request meant for the upstream url and then use the
   * following placeholders to have the endpoint populate them with card data:
   * ${ccn}, ${cvv}, ${fullName}, ${lastName}, ${firstName}, ${cardType}, ${mm},
   * ${yy}, and ${yyyy}. Supports GET/PUT/POST/DELETE.
   *
   * @param {object} body Token and gateway information.
   *
   * @param {string} body.url URL to use on the payment gateway request.
   *
   * @param {string} body.httpMethod HTTP method to use on the payment gateway
   * request.
   *
   * @param {array} [body.headers] Headers to use on the payment gateway request.
   *
   * @param {string} [body.body] Body to use on the payment gateway request.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  cardProxyWithHttpOperationResponse(body, cardToken, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._cardProxy(body, cardToken, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Send detokenized card data and transaction info to a payment
   * gateway.
   *
   * This endpoint allows you to use a stored card without touching the card
   * data. Build out the request meant for the upstream url and then use the
   * following placeholders to have the endpoint populate them with card data:
   * ${ccn}, ${cvv}, ${fullName}, ${lastName}, ${firstName}, ${cardType}, ${mm},
   * ${yy}, and ${yyyy}. Supports GET/PUT/POST/DELETE.
   *
   * @param {object} body Token and gateway information.
   *
   * @param {string} body.url URL to use on the payment gateway request.
   *
   * @param {string} body.httpMethod HTTP method to use on the payment gateway
   * request.
   *
   * @param {array} [body.headers] Headers to use on the payment gateway request.
   *
   * @param {string} [body.body] Body to use on the payment gateway request.
   *
   * @param {string} cardToken Card token.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] Expiring key for temporary access.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  cardProxy(body, cardToken, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._cardProxy(body, cardToken, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._cardProxy(body, cardToken, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get a url to the card processing UI.
   *
   * The card processing UI allows your customers to enter their card data and
   * process upstream with the payment gateway without your app touching it.
   * Build out the request meant for the upstream url and then use the following
   * placeholders to have the endpoint populate them with card data: ${total},
   * ${ccn}, ${cvv}, ${fullName}, ${lastName}, ${firstName}, ${cardType}, ${mm},
   * ${yy}, and ${yyyy}. Supports GET/PUT/POST/DELETE. The customer is redirected
   * back to your app (callback url) via POST with the parameter eVsessionId. You
   * can then use /cardvault/process/sessions/ to determine the adjudication. The
   * session information is available for 72 hours. If the customer choses to
   * save their card, it will be available through the sessions endpoint. If the
   * customer chooses to cancel or if the form timeouts, evException will have a
   * value within the POST callback. For cancels, evException's value will be
   * 'cancel'. For timeouts, the evException's value will be 'timeout'. There are
   * multiple ways to integrate the card process form. You can use it within a
   * popup, redirect or simple iframe.
   *
   * @param {object} body Gateway and cart information.
   *
   * @param {object} body.gatewayRequest
   *
   * @param {string} body.gatewayRequest.url URL to use on the payment gateway
   * request.
   *
   * @param {string} body.gatewayRequest.httpMethod HTTP method to use on the
   * payment gateway request.
   *
   * @param {array} [body.gatewayRequest.headers] Headers to use on the payment
   * gateway request.
   *
   * @param {string} [body.gatewayRequest.body] Body to use on the payment
   * gateway request.
   *
   * @param {object} body.cart
   *
   * @param {string} body.cart.cultureCode ISO 639-1 (language) and ISO 3166-1
   * (country) code.
   *
   * @param {array} body.cart.cartItems List of cart items.
   *
   * @param {number} body.cart.total Total of the cart item amounts. The total is
   * validated against the
   * sum of the cart item amounts.
   *
   * @param {boolean} body.cart.gatewayIntegersOnly Some payment gateways only
   * accept integers. If true, it will multiply
   * the total by 100. For instance, 10.01 will be submitted to the gateway
   * as 1001.
   *
   * @param {string} callbackUrl URL the user is redirected to after storing the
   * card.
   *
   * @param {boolean} showTimer Show or hide the timer.
   *
   * @param {boolean} showCard Show or hide the card visual.
   *
   * @param {number} ttl Form session time to live in seconds. After it expires,
   * the form can no
   * longer be used.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {boolean} [options.preserveFormat] If true, a Luhn passable token is
   * returned consisting of the original first six and last four.
   *
   * @param {string} [options.cardTypes] Card types, comma delimited. Omit for
   * any card.
   * (amex, diners_club_carte_blanche, diners_club_international,
   * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro,
   * uatp, mir).
   *
   * @param {string} [options.pageHeader] Configurable page header.
   *
   * @param {string} [options.submitButtonText] Text of the submit button.
   *
   * @param {string} [options.language] The language to use on the form.
   * Currently en (English), es (Spanish),
   * fr (French), and zh-Hans (Chinese simplified) are available.
   *
   * @param {string} [options.submitButtonColor] The hex color of the submit
   * button.
   *
   * @param {string} [options.cancelButtonColor] The hex color of the cancel
   * button.
   *
   * @param {string} [options.pageColor] The hex color of the page background.
   *
   * @param {string} [options.submitButtonTextColor] The hex color of the submit
   * button text.
   *
   * @param {string} [options.cancelButtonTextColor] The hex color of the cancel
   * button text.
   *
   * @param {string} [options.pageTextColor] The hex color of the page text.
   *
   * @param {string} [options.cartTableBorderColor] The hex color of the cart
   * table header and border.
   *
   * @param {string} [options.cartTableAlternateRowColor] The hex color of the
   * cart table's alternating rows.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getCardProcessFormWithHttpOperationResponse(body, callbackUrl, showTimer, showCard, ttl, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getCardProcessForm(body, callbackUrl, showTimer, showCard, ttl, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get a url to the card processing UI.
   *
   * The card processing UI allows your customers to enter their card data and
   * process upstream with the payment gateway without your app touching it.
   * Build out the request meant for the upstream url and then use the following
   * placeholders to have the endpoint populate them with card data: ${total},
   * ${ccn}, ${cvv}, ${fullName}, ${lastName}, ${firstName}, ${cardType}, ${mm},
   * ${yy}, and ${yyyy}. Supports GET/PUT/POST/DELETE. The customer is redirected
   * back to your app (callback url) via POST with the parameter eVsessionId. You
   * can then use /cardvault/process/sessions/ to determine the adjudication. The
   * session information is available for 72 hours. If the customer choses to
   * save their card, it will be available through the sessions endpoint. If the
   * customer chooses to cancel or if the form timeouts, evException will have a
   * value within the POST callback. For cancels, evException's value will be
   * 'cancel'. For timeouts, the evException's value will be 'timeout'. There are
   * multiple ways to integrate the card process form. You can use it within a
   * popup, redirect or simple iframe.
   *
   * @param {object} body Gateway and cart information.
   *
   * @param {object} body.gatewayRequest
   *
   * @param {string} body.gatewayRequest.url URL to use on the payment gateway
   * request.
   *
   * @param {string} body.gatewayRequest.httpMethod HTTP method to use on the
   * payment gateway request.
   *
   * @param {array} [body.gatewayRequest.headers] Headers to use on the payment
   * gateway request.
   *
   * @param {string} [body.gatewayRequest.body] Body to use on the payment
   * gateway request.
   *
   * @param {object} body.cart
   *
   * @param {string} body.cart.cultureCode ISO 639-1 (language) and ISO 3166-1
   * (country) code.
   *
   * @param {array} body.cart.cartItems List of cart items.
   *
   * @param {number} body.cart.total Total of the cart item amounts. The total is
   * validated against the
   * sum of the cart item amounts.
   *
   * @param {boolean} body.cart.gatewayIntegersOnly Some payment gateways only
   * accept integers. If true, it will multiply
   * the total by 100. For instance, 10.01 will be submitted to the gateway
   * as 1001.
   *
   * @param {string} callbackUrl URL the user is redirected to after storing the
   * card.
   *
   * @param {boolean} showTimer Show or hide the timer.
   *
   * @param {boolean} showCard Show or hide the card visual.
   *
   * @param {number} ttl Form session time to live in seconds. After it expires,
   * the form can no
   * longer be used.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {boolean} [options.preserveFormat] If true, a Luhn passable token is
   * returned consisting of the original first six and last four.
   *
   * @param {string} [options.cardTypes] Card types, comma delimited. Omit for
   * any card.
   * (amex, diners_club_carte_blanche, diners_club_international,
   * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro,
   * uatp, mir).
   *
   * @param {string} [options.pageHeader] Configurable page header.
   *
   * @param {string} [options.submitButtonText] Text of the submit button.
   *
   * @param {string} [options.language] The language to use on the form.
   * Currently en (English), es (Spanish),
   * fr (French), and zh-Hans (Chinese simplified) are available.
   *
   * @param {string} [options.submitButtonColor] The hex color of the submit
   * button.
   *
   * @param {string} [options.cancelButtonColor] The hex color of the cancel
   * button.
   *
   * @param {string} [options.pageColor] The hex color of the page background.
   *
   * @param {string} [options.submitButtonTextColor] The hex color of the submit
   * button text.
   *
   * @param {string} [options.cancelButtonTextColor] The hex color of the cancel
   * button text.
   *
   * @param {string} [options.pageTextColor] The hex color of the page text.
   *
   * @param {string} [options.cartTableBorderColor] The hex color of the cart
   * table header and border.
   *
   * @param {string} [options.cartTableAlternateRowColor] The hex color of the
   * cart table's alternating rows.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getCardProcessForm(body, callbackUrl, showTimer, showCard, ttl, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getCardProcessForm(body, callbackUrl, showTimer, showCard, ttl, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getCardProcessForm(body, callbackUrl, showTimer, showCard, ttl, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get card process session information.
   *
   * Obtain the results from the gateway and retrieve the card token if the
   * customer decided to save it.
   *
   * @param {uuid} id Session ID
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getCardProcessSessionWithHttpOperationResponse(id, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getCardProcessSession(id, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get card process session information.
   *
   * Obtain the results from the gateway and retrieve the card token if the
   * customer decided to save it.
   *
   * @param {uuid} id Session ID
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getCardProcessSession(id, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getCardProcessSession(id, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getCardProcessSession(id, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get a url to the card store UI.
   *
   * The card store form allows your app to store and later use customer card
   * data without touching it. After the cardTtl expires, the card is deleted. If
   * the user decides to save the card, the card is stored permanently. If you're
   * seeking to permanently store the card outside of a transaction (wallet
   * style), set walletSave to true. If you set walletSave to true, the
   * buttonText and cardTtl are overriden. If walletSave is true the CVV isn't
   * requested. If you intend to use the card in a transaction within 30 minutes,
   * set walletSave to false. On callback, your app will receive via POST the
   * card token within the parameter eVtoken. If the customer chooses to cancel
   * or if the form timeouts, the evException parameter will contain the reason.
   * For cancels, evException's value will be 'cancel'. For timeouts,
   * evException's value will be 'timeout'. If embedFormForControl is set to
   * true, pass 'submit' as a message over to the iframe to submit the form. On
   * response, the parent will receive an object that consists of the status, the
   * token, and CardModel object. There are multiple ways to integrate the card
   * store form. You can use it within a popup, redirect, simple iframe, or
   * iframe where the parent page has control to submit the form. You can find
   * example code for the advanced iframe integration on
   * [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).
   *
   * @param {boolean} showTimer Show or hide the timer.
   *
   * @param {boolean} showCard Show or hide the card visual.
   *
   * @param {boolean} walletSave Make true to store the card in your app's
   * wallet. This overrides
   * the cardTtl and buttonText values. The CVV isn't requested if true.
   * If you intend to use the card in a transaction within 30 minutes,
   * set walletSave to false.
   *
   * @param {boolean} embedFormForControl If true, it removes its buttons and
   * any additional padding/spacing, and enables the windows interface for 2-way
   * comms.
   *
   * @param {number} ttl Form session time to live in seconds. After it expires,
   * the form can no
   * longer be used.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {number} [options.cardTtl] The card's time to live in seconds
   * (60-1800 secs).
   * Once expired the card is deleted from the vault. Use the
   * /cardvault/cards/ttl
   * endpoint to extend it. This field is required if walletSave is false.
   *
   * @param {boolean} [options.preserveFormat] If true, a Luhn passable token is
   * returned consisting of the original first six and last four.
   *
   * @param {string} [options.cardTypes] Card types, comma delimited. Omit for
   * any card.
   * (amex, diners_club_carte_blanche, diners_club_international,
   * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro,
   * uatp, mir).
   *
   * @param {string} [options.callbackUrl] URL the user is redirected to after
   * storing the card.
   *
   * @param {string} [options.parentUrl] The parent page URL. The store form uses
   * it when embedFormForControl
   * is true to communicate with the parent window.
   *
   * @param {string} [options.pageHeader] Configurable page header.
   *
   * @param {string} [options.language] The language to use on the form.
   * Currently en (English), es (Spanish),
   * fr (French), and zh-Hans (Chinese simplified) are available.
   *
   * @param {string} [options.submitButtonText] Text of the submit button.
   *
   * @param {string} [options.submitButtonColor] The hex color of the submit
   * button.
   *
   * @param {string} [options.cancelButtonColor] The hex color of the cancel
   * button.
   *
   * @param {string} [options.pageColor] The hex color of the page background.
   *
   * @param {string} [options.submitButtonTextColor] The hex color of the submit
   * button text.
   *
   * @param {string} [options.cancelButtonTextColor] The hex color of the cancel
   * button text.
   *
   * @param {string} [options.pageTextColor] The hex color of the page text.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getCardStoreFormWithHttpOperationResponse(showTimer, showCard, walletSave, embedFormForControl, ttl, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getCardStoreForm(showTimer, showCard, walletSave, embedFormForControl, ttl, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get a url to the card store UI.
   *
   * The card store form allows your app to store and later use customer card
   * data without touching it. After the cardTtl expires, the card is deleted. If
   * the user decides to save the card, the card is stored permanently. If you're
   * seeking to permanently store the card outside of a transaction (wallet
   * style), set walletSave to true. If you set walletSave to true, the
   * buttonText and cardTtl are overriden. If walletSave is true the CVV isn't
   * requested. If you intend to use the card in a transaction within 30 minutes,
   * set walletSave to false. On callback, your app will receive via POST the
   * card token within the parameter eVtoken. If the customer chooses to cancel
   * or if the form timeouts, the evException parameter will contain the reason.
   * For cancels, evException's value will be 'cancel'. For timeouts,
   * evException's value will be 'timeout'. If embedFormForControl is set to
   * true, pass 'submit' as a message over to the iframe to submit the form. On
   * response, the parent will receive an object that consists of the status, the
   * token, and CardModel object. There are multiple ways to integrate the card
   * store form. You can use it within a popup, redirect, simple iframe, or
   * iframe where the parent page has control to submit the form. You can find
   * example code for the advanced iframe integration on
   * [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).
   *
   * @param {boolean} showTimer Show or hide the timer.
   *
   * @param {boolean} showCard Show or hide the card visual.
   *
   * @param {boolean} walletSave Make true to store the card in your app's
   * wallet. This overrides
   * the cardTtl and buttonText values. The CVV isn't requested if true.
   * If you intend to use the card in a transaction within 30 minutes,
   * set walletSave to false.
   *
   * @param {boolean} embedFormForControl If true, it removes its buttons and
   * any additional padding/spacing, and enables the windows interface for 2-way
   * comms.
   *
   * @param {number} ttl Form session time to live in seconds. After it expires,
   * the form can no
   * longer be used.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {number} [options.cardTtl] The card's time to live in seconds
   * (60-1800 secs).
   * Once expired the card is deleted from the vault. Use the
   * /cardvault/cards/ttl
   * endpoint to extend it. This field is required if walletSave is false.
   *
   * @param {boolean} [options.preserveFormat] If true, a Luhn passable token is
   * returned consisting of the original first six and last four.
   *
   * @param {string} [options.cardTypes] Card types, comma delimited. Omit for
   * any card.
   * (amex, diners_club_carte_blanche, diners_club_international,
   * jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro,
   * uatp, mir).
   *
   * @param {string} [options.callbackUrl] URL the user is redirected to after
   * storing the card.
   *
   * @param {string} [options.parentUrl] The parent page URL. The store form uses
   * it when embedFormForControl
   * is true to communicate with the parent window.
   *
   * @param {string} [options.pageHeader] Configurable page header.
   *
   * @param {string} [options.language] The language to use on the form.
   * Currently en (English), es (Spanish),
   * fr (French), and zh-Hans (Chinese simplified) are available.
   *
   * @param {string} [options.submitButtonText] Text of the submit button.
   *
   * @param {string} [options.submitButtonColor] The hex color of the submit
   * button.
   *
   * @param {string} [options.cancelButtonColor] The hex color of the cancel
   * button.
   *
   * @param {string} [options.pageColor] The hex color of the page background.
   *
   * @param {string} [options.submitButtonTextColor] The hex color of the submit
   * button text.
   *
   * @param {string} [options.cancelButtonTextColor] The hex color of the cancel
   * button text.
   *
   * @param {string} [options.pageTextColor] The hex color of the page text.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getCardStoreForm(showTimer, showCard, walletSave, embedFormForControl, ttl, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getCardStoreForm(showTimer, showCard, walletSave, embedFormForControl, ttl, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getCardStoreForm(showTimer, showCard, walletSave, embedFormForControl, ttl, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get a url to the CVV store UI.
   *
   * The CVV store form allows your app to temporarily store the CVV until
   * authorization. The CVV ttl is set to the card's ttl. If the card has a ttl
   * of -1, the CVV ttl will be set to 1800 seconds. If autoSave is true, the
   * callback will not trigger so the client app will need to verify the cvv ttl
   * for its existence. There are multiple ways to integrate the cvv form. You
   * can use it within a popup, redirect, simple iframe, (previous 3 can use
   * autosave) or iframe where the parent page has control to submit the form.
   * You can find example code for the advanced iframe integration on
   * [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).
   *
   * @param {string} cardToken Card token.
   *
   * @param {boolean} showTimer Show or hide the timer.
   *
   * @param {boolean} showCancelButton Show or hide the cancel button.
   *
   * @param {boolean} autoSave If true, the buttons and header are removed, and
   * cvv will be autosaved after user entry.
   * The callback will not trigger so the client app will need to verify the cvv
   * ttl for its existence.
   *
   * @param {boolean} embedFormForControl If true, it removes its buttons and
   * any additional padding/spacing, and enables the windows interface for 2-way
   * comms.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {string} [options.callbackUrl] URL the user is redirected to after
   * storing the card.
   *
   * @param {string} [options.parentUrl] The parent page URL. The store form uses
   * it when embedFormForControl
   * is true to communicate with the parent window.
   *
   * @param {string} [options.pageHeader] Configurable page header.
   *
   * @param {string} [options.language] The language to use on the form.
   * Currently en (English), es (Spanish),
   * fr (French), and zh-Hans (Chinese simplified) are available.
   *
   * @param {string} [options.submitButtonText] Text of the submit button.
   *
   * @param {string} [options.submitButtonColor] The hex color of the submit
   * button.
   *
   * @param {string} [options.cancelButtonColor] The hex color of the cancel
   * button.
   *
   * @param {string} [options.pageColor] The hex color of the page background.
   *
   * @param {string} [options.submitButtonTextColor] The hex color of the submit
   * button text.
   *
   * @param {string} [options.cancelButtonTextColor] The hex color of the cancel
   * button text.
   *
   * @param {string} [options.pageTextColor] The hex color of the page text.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getCvvStoreFormWithHttpOperationResponse(cardToken, showTimer, showCancelButton, autoSave, embedFormForControl, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getCvvStoreForm(cardToken, showTimer, showCancelButton, autoSave, embedFormForControl, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get a url to the CVV store UI.
   *
   * The CVV store form allows your app to temporarily store the CVV until
   * authorization. The CVV ttl is set to the card's ttl. If the card has a ttl
   * of -1, the CVV ttl will be set to 1800 seconds. If autoSave is true, the
   * callback will not trigger so the client app will need to verify the cvv ttl
   * for its existence. There are multiple ways to integrate the cvv form. You
   * can use it within a popup, redirect, simple iframe, (previous 3 can use
   * autosave) or iframe where the parent page has control to submit the form.
   * You can find example code for the advanced iframe integration on
   * [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).
   *
   * @param {string} cardToken Card token.
   *
   * @param {boolean} showTimer Show or hide the timer.
   *
   * @param {boolean} showCancelButton Show or hide the cancel button.
   *
   * @param {boolean} autoSave If true, the buttons and header are removed, and
   * cvv will be autosaved after user entry.
   * The callback will not trigger so the client app will need to verify the cvv
   * ttl for its existence.
   *
   * @param {boolean} embedFormForControl If true, it removes its buttons and
   * any additional padding/spacing, and enables the windows interface for 2-way
   * comms.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {string} [options.callbackUrl] URL the user is redirected to after
   * storing the card.
   *
   * @param {string} [options.parentUrl] The parent page URL. The store form uses
   * it when embedFormForControl
   * is true to communicate with the parent window.
   *
   * @param {string} [options.pageHeader] Configurable page header.
   *
   * @param {string} [options.language] The language to use on the form.
   * Currently en (English), es (Spanish),
   * fr (French), and zh-Hans (Chinese simplified) are available.
   *
   * @param {string} [options.submitButtonText] Text of the submit button.
   *
   * @param {string} [options.submitButtonColor] The hex color of the submit
   * button.
   *
   * @param {string} [options.cancelButtonColor] The hex color of the cancel
   * button.
   *
   * @param {string} [options.pageColor] The hex color of the page background.
   *
   * @param {string} [options.submitButtonTextColor] The hex color of the submit
   * button text.
   *
   * @param {string} [options.cancelButtonTextColor] The hex color of the cancel
   * button text.
   *
   * @param {string} [options.pageTextColor] The hex color of the page text.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getCvvStoreForm(cardToken, showTimer, showCancelButton, autoSave, embedFormForControl, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getCvvStoreForm(cardToken, showTimer, showCancelButton, autoSave, embedFormForControl, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getCvvStoreForm(cardToken, showTimer, showCancelButton, autoSave, embedFormForControl, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get a listing of all supported cultures and currencies.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {string} [options.cultureCode] ISO 639-1 (language) and ISO 3166-1
   * (country) code.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getCulturesWithHttpOperationResponse(xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getCultures(xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get a listing of all supported cultures and currencies.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {string} [options.cultureCode] ISO 639-1 (language) and ISO 3166-1
   * (country) code.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getCultures(xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getCultures(xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getCultures(xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Store a secret.
   *
   * Supports up to 5,000 plaintext objects per request. Plaintext strings must
   * be less than 1000 characters in length. The customIdentifier attribute ties
   * your unencrypted data to the tokens. The customIdentifier is not stored
   * within the vault.
   *
   * @param {array} body Your secrets to vault.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  storeDataSecretsWithHttpOperationResponse(body, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._storeDataSecrets(body, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Store a secret.
   *
   * Supports up to 5,000 plaintext objects per request. Plaintext strings must
   * be less than 1000 characters in length. The customIdentifier attribute ties
   * your unencrypted data to the tokens. The customIdentifier is not stored
   * within the vault.
   *
   * @param {array} body Your secrets to vault.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  storeDataSecrets(body, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._storeDataSecrets(body, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._storeDataSecrets(body, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get a secret by token.
   *
   * The ephemeralKey is a one time use expiring key that allows an external
   * client to obtain the token's secret. To generate one, use the
   * datavault/secrets/ephemeralKey endpoint.
   *
   * @param {string} token Reference to the vaulted secret.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] One time use expiring key.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getDataSecretWithHttpOperationResponse(token, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getDataSecret(token, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get a secret by token.
   *
   * The ephemeralKey is a one time use expiring key that allows an external
   * client to obtain the token's secret. To generate one, use the
   * datavault/secrets/ephemeralKey endpoint.
   *
   * @param {string} token Reference to the vaulted secret.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] One time use expiring key.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getDataSecret(token, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getDataSecret(token, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getDataSecret(token, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Delete a secret.
   *
   * @param {string} token Reference to the vaulted secret.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  deleteDataSecretWithHttpOperationResponse(token, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._deleteDataSecret(token, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Delete a secret.
   *
   * @param {string} token Reference to the vaulted secret.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  deleteDataSecret(token, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._deleteDataSecret(token, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._deleteDataSecret(token, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Search by plaintext.
   *
   * Exact matches will only be returned and is case sensitive.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.body] Text to search within the vault. Exact
   * matches will only be returned and is case sensitive.
   *
   * @param {string} options.body.plaintext Secret text.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  searchDataSecretsWithHttpOperationResponse(xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._searchDataSecrets(xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Search by plaintext.
   *
   * Exact matches will only be returned and is case sensitive.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.body] Text to search within the vault. Exact
   * matches will only be returned and is case sensitive.
   *
   * @param {string} options.body.plaintext Secret text.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  searchDataSecrets(xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._searchDataSecrets(xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._searchDataSecrets(xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get an ephemeral key for a specific token and client.
   *
   * The ephemeralKey is a one time use expiring key that allows an external
   * client to obtain the token's secret. The destinationClientId is a valid
   * Enigma Vault clientId of the destination app. The time to live (ttl) is in
   * seconds.
   *
   * @param {string} token Reference to the vaulted secret.
   *
   * @param {string} destinationClientId Enigma Vault client granted use of the
   * ephemeralKey.
   *
   * @param {number} ttl Time to live in seconds, max of 300.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getDataEphemeralKeyWithHttpOperationResponse(token, destinationClientId, ttl, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getDataEphemeralKey(token, destinationClientId, ttl, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get an ephemeral key for a specific token and client.
   *
   * The ephemeralKey is a one time use expiring key that allows an external
   * client to obtain the token's secret. The destinationClientId is a valid
   * Enigma Vault clientId of the destination app. The time to live (ttl) is in
   * seconds.
   *
   * @param {string} token Reference to the vaulted secret.
   *
   * @param {string} destinationClientId Enigma Vault client granted use of the
   * ephemeralKey.
   *
   * @param {number} ttl Time to live in seconds, max of 300.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getDataEphemeralKey(token, destinationClientId, ttl, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getDataEphemeralKey(token, destinationClientId, ttl, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getDataEphemeralKey(token, destinationClientId, ttl, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get a url to upload a file.
   *
   * The url is used to upload (PUT) a file into the vault. The url has an
   * exipration of five minutes. The file size cannot exceed 5 gigabytes. A
   * websocket url is provided so that the status of the file can be tracked in
   * realtime.
   *
   * @param {string} contentType The MIME type associated with the file.
   *
   * @param {string} fileExtension The file extension without the leading .
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getUploadUrlWithHttpOperationResponse(contentType, fileExtension, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getUploadUrl(contentType, fileExtension, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get a url to upload a file.
   *
   * The url is used to upload (PUT) a file into the vault. The url has an
   * exipration of five minutes. The file size cannot exceed 5 gigabytes. A
   * websocket url is provided so that the status of the file can be tracked in
   * realtime.
   *
   * @param {string} contentType The MIME type associated with the file.
   *
   * @param {string} fileExtension The file extension without the leading .
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getUploadUrl(contentType, fileExtension, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getUploadUrl(contentType, fileExtension, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getUploadUrl(contentType, fileExtension, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get the status of a file.
   *
   * This endpoint has been deprecated because the file status is now provided
   * through a websocket API.
   *
   * @param {string} fileName Tokenized file name.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getFileStatusWithHttpOperationResponse(fileName, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getFileStatus(fileName, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get the status of a file.
   *
   * This endpoint has been deprecated because the file status is now provided
   * through a websocket API.
   *
   * @param {string} fileName Tokenized file name.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getFileStatus(fileName, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getFileStatus(fileName, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getFileStatus(fileName, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get a url to decrypt and download the file.
   *
   * The url is used to download the file out of the vault. The url has an
   * exipration of five minutes. When aSync is set to true for large files, a
   * websocket API url is returned so that the file status can be monitored in
   * real time. When the file is finished decrypting, the download url is
   * provided through the websocket connection.
   *
   * @param {string} fileName Tokenized file name.
   *
   * @param {boolean} aSync Set to true to decrypt large files; you'll use the
   * websocket API for notifications.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] One time use expiring key.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getDownloadUrlWithHttpOperationResponse(fileName, aSync, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getDownloadUrl(fileName, aSync, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get a url to decrypt and download the file.
   *
   * The url is used to download the file out of the vault. The url has an
   * exipration of five minutes. When aSync is set to true for large files, a
   * websocket API url is returned so that the file status can be monitored in
   * real time. When the file is finished decrypting, the download url is
   * provided through the websocket connection.
   *
   * @param {string} fileName Tokenized file name.
   *
   * @param {boolean} aSync Set to true to decrypt large files; you'll use the
   * websocket API for notifications.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {uuid} [options.ephemeralKey] One time use expiring key.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getDownloadUrl(fileName, aSync, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getDownloadUrl(fileName, aSync, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getDownloadUrl(fileName, aSync, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Delete a file.
   *
   * On successful deletion, a 204 response is returned.
   *
   * @param {string} fileName Tokenized file name.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  deleteFileWithHttpOperationResponse(fileName, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._deleteFile(fileName, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Delete a file.
   *
   * On successful deletion, a 204 response is returned.
   *
   * @param {string} fileName Tokenized file name.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  deleteFile(fileName, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._deleteFile(fileName, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._deleteFile(fileName, xApiVersion, options, optionalCallback);
    }
  }

  /**
   * @summary Get an ephemeral key for a specific fileName and client.
   *
   * The ephemeralKey is a one time use expiring key that allows an external
   * client to obtain a download url. The destinationClientId is a valid Enigma
   * Vault clientId of the destination app. The time to live (ttl) is in seconds.
   *
   * @param {string} fileName Tokenized file name.
   *
   * @param {string} destinationClientId Enigma Vault client granted use of the
   * ephemeralKey.
   *
   * @param {number} ttl Time to live in seconds, max of 300.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @returns {Promise} A promise is returned
   *
   * @resolve {HttpOperationResponse<Object>} - The deserialized result object.
   *
   * @reject {Error} - The error object.
   */
  getFileEphemeralKeyWithHttpOperationResponse(fileName, destinationClientId, ttl, xApiVersion, options) {
    let client = this;
    let self = this;
    return new Promise((resolve, reject) => {
      self._getFileEphemeralKey(fileName, destinationClientId, ttl, xApiVersion, options, (err, result, request, response) => {
        let httpOperationResponse = new msRest.HttpOperationResponse(request, response);
        httpOperationResponse.body = result;
        if (err) { reject(err); }
        else { resolve(httpOperationResponse); }
        return;
      });
    });
  }

  /**
   * @summary Get an ephemeral key for a specific fileName and client.
   *
   * The ephemeralKey is a one time use expiring key that allows an external
   * client to obtain a download url. The destinationClientId is a valid Enigma
   * Vault clientId of the destination app. The time to live (ttl) is in seconds.
   *
   * @param {string} fileName Tokenized file name.
   *
   * @param {string} destinationClientId Enigma Vault client granted use of the
   * ephemeralKey.
   *
   * @param {number} ttl Time to live in seconds, max of 300.
   *
   * @param {string} xApiVersion The requested API version
   *
   * @param {object} [options] Optional Parameters.
   *
   * @param {object} [options.customHeaders] Headers that will be added to the
   * request
   *
   * @param {function} [optionalCallback] - The optional callback.
   *
   * @returns {function|Promise} If a callback was passed as the last parameter
   * then it returns the callback else returns a Promise.
   *
   * {Promise} A promise is returned
   *
   *                      @resolve {Object} - The deserialized result object.
   *
   *                      @reject {Error} - The error object.
   *
   * {function} optionalCallback(err, result, request, response)
   *
   *                      {Error}  err        - The Error object if an error occurred, null otherwise.
   *
   *                      {object} [result]   - The deserialized result object if an error did not occur.
   *
   *                      {object} [request]  - The HTTP Request object if an error did not occur.
   *
   *                      {stream} [response] - The HTTP Response stream if an error did not occur.
   */
  getFileEphemeralKey(fileName, destinationClientId, ttl, xApiVersion, options, optionalCallback) {
    let client = this;
    let self = this;
    if (!optionalCallback && typeof options === 'function') {
      optionalCallback = options;
      options = null;
    }
    if (!optionalCallback) {
      return new Promise((resolve, reject) => {
        self._getFileEphemeralKey(fileName, destinationClientId, ttl, xApiVersion, options, (err, result, request, response) => {
          if (err) { reject(err); }
          else { resolve(result); }
          return;
        });
      });
    } else {
      return self._getFileEphemeralKey(fileName, destinationClientId, ttl, xApiVersion, options, optionalCallback);
    }
  }

}

module.exports = EnigmaVaultAPI;
module.exports['default'] = EnigmaVaultAPI;
module.exports.EnigmaVaultAPI = EnigmaVaultAPI;
module.exports.EnigmaVaultAPIModels = models;
